OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Acceso denegado",
    "Invalid request" : "Solicitud inválida",
    "Files not found" : "Archivos no encontrados",
    "File not found" : "Archivo no encontrado",
    "Not permitted" : "No permitido",
    "Download failed" : "Error en la descarga",
    "The required folder was not found" : "No se encontró la carpeta necesaria",
    "You don't have enough permission to create" : "No tiene suficiente permiso para crear",
    "Template not found" : "Plantilla no encontrada",
    "Can't create file" : "No se puede crear archivo",
    "Format is not supported" : "Formato no se soporta",
    "Conversion is not required" : "No se requiere conversión",
    "Failed to download converted file" : "Fallo en la descarga del archivo convertido",
    "ONLYOFFICE app is not configured. Please contact admin" : "Aplicación ONLYOFFICE no está configurada. Por favor, contacte con admin",
    "FileId is empty" : "Id del archivo es vacío",
    "You do not have enough permissions to view the file" : "No tiene suficientes permisos para ver el archivo",
    "Error occurred in the document service" : "Se ha producido un error en el servicio de documentos",
    "Not supported version" : "Versión no compatible",
    "ONLYOFFICE cannot be reached. Please contact admin" : "No se puede acceder al ONLYOFFICE. Por favor, contacte con admin",
    "Loading, please wait." : "Cargando, espere, por favor.",
    "File created" : "Archivo creado",
    "Open in ONLYOFFICE" : "Abrir en ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Convertir con ONLYOFFICE",
    "Document" : "Documento",
    "Spreadsheet" : "Hoja de cálculo",
    "Presentation" : "Presentación",
    "Error when trying to connect" : "Error al intentar establecer la conexión",
    "Settings have been successfully updated" : "Ajustes han sido actualizados con éxito",
    "Server can't read xml" : "Servidor no puede leer xml",
    "Bad Response. Errors: " : "Respuesta Mala. Errores:",
    "Documentation" : "Documentación",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "Ubicación del ONLYOFFICE Docs especifica la dirección del servidor con los servicios de documentos instalados. Por favor, cambie '<documentserver>' para la dirección de servidor en la línea inferior.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Aplicación de encriptación está activada, esta aplicación no puede funcionar. Usted puede seguir trabajando con la aplicación si activa la clave maestra.",
    "ONLYOFFICE Docs address" : "Dirección de ONLYOFFICE Docs",
    "Advanced server settings" : "Ajustes de servidor avanzados",
    "ONLYOFFICE Docs address for internal requests from the server" : "Dirección de ONLYOFFICE Docs para solicitudes internas del servidor",
    "Server address for internal requests from ONLYOFFICE Docs" : "Dirección de servidor para solicitudes internas del ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Clave secreta (deje en blanco o desactive)",
    "Open file in the same tab" : "Abrir archivo en la misma pestaña",
    "The default application for opening the format" : "La aplicación predeterminada para abrir el formato",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Abrir archivo para editar (debido a las restricciones de formato los datos podrían perderse al guardar en los formatos de la siguiente lista)",
    "View details" : "Ver detalles",
    "Save" : "Guardar",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Contenido Mixto Activo no está permitido. Se requiere la dirección HTTPS para ONLYOFFICE Docs.",
    "Restrict access to editors to following groups" : "Restringir el acceso a editores a siguientes grupos",
    "review" : "revista",
    "form filling" : "relleno de formulario",
    "comment" : "comentarios",
    "custom filter" : "filtro personalizado",
    "download" : "descargar",
    "Server settings" : "Ajustes de servidor",
    "Common settings" : "Ajustes comunes",
    "Editor customization settings" : "Ajustes del editor",
    "The customization section allows personalizing the editor interface" : "La sección de personalización permite customizar la interfaz del editor",
    "Display Chat menu button" : "Mostrar el botón de Chat",
    "Display the header more compact" : "Mostrar el encabezado más compacto",
    "Display Feedback & Support menu button" : "Mostrar el botón de Feedback y Soporte",
    "Display Help menu button" : "Mostrar el botón de Ayuda",
    "Display monochrome toolbar header" : "Mostrar el encabezado monocromático de la barra de herramientas",
    "Save as" : "Guardar como",
    "File saved" : "El archivo ha sido guardado",
    "Insert image" : "Insertar imagen",
    "Select recipients" : "Seleccionar destinatarios",
    "Connect to demo ONLYOFFICE Docs server" : "Conectarse al servidor de ONLYOFFICE Docs de demostración",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Este es un servidor de pruebas público, por favor no lo uses para tus datos confidenciales. El servidor estará disponible durante un período de 30 días.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "El período de prueba de 30 días ha terminado, ya no puedes conectarte al servidor de ONLYOFFICE Docs de demostración",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Estás usando el servidor de ONLYOFFICE Docs de demostración. Por favor, no almacenes tus datos confidenciales aquí.",
    "Select file to compare" : "Seleccione un archivo para comparar",
    "Review mode for viewing": "Modo de revisión para para visualización",
    "Markup": "Cambios",
    "Final": "Final",
    "Original": "Original",
    "version": "versión",
    "Disable certificate verification (insecure)": "Desactivar la verificación de certificados (inseguro)",
    "Keep intermediate versions when editing (forcesave)": "Mantener las versiones intermedias durante la edición (forzar guardar)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Usar ONLYOFFICE para generar una vista previa del documento (ocupará espacio en el disco)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Guardar los metadatos de cada versión al editar el documento (ocupará espacio en el disco)",
    "Clear": "Limpiar",
    "All history successfully deleted": "Todo el historial se ha eliminado correctamente",
    "Create": "Crear",
    "Select template" : "Seleccionar plantilla",
    "Invalid file provided" : "Archivo proporcionado no válido",
    "Empty": "Vacío",
    "Error" : "Error",
    "Add a new template": "Añadir una plantilla nueva",
    "Template already exists": "La plantilla ya existe",
    "Template must be in OOXML format": "La plantilla debe tener el formato OOXML",
    "Template successfully added": "La plantilla se agregó correctamente",
    "Template successfully deleted": "La plantilla se eliminó correctamente",
    "Common templates": "Plantillas comunes",
    "Failed to delete template": "No se pudo eliminar la plantilla",
    "File has been converted. Its content might look different.": "El archivo se ha convertido. Su contenido puede ser distinto.",
    "Download as": "Descargar como",
    "Download": "Descargar",
    "Origin format": "Formato original",
    "Failed to send notification": "Error al enviar la notificación",
    "Notification sent successfully": "Notificación enviada correctamente",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s le ha mencionado en %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Elija un formato para convertir {fileName}",
    "Form template": "Plantilla de formulario",
    "Form template from existing text file": "Plantilla de formulario desde un archivo de texto existente",
    "Create form": "Crear formulario",
    "Fill in form in ONLYOFFICE": "Rellenar el formulario en ONLYOFFICE",
    "Create new Form template": "Crear nueva plantilla de formulario",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Por favor, actualice ONLYOFFICE Docs a la versión 7.0 para poder trabajar con formularios rellenables en línea",
    "Security": "Seguridad",
    "Run document macros": "Ejecutar macros de documentos",
    "Default editor theme": "Tema del editor predeterminado",
    "Light": "Claro",
    "Classic Light": "Clásico claro",
    "Dark": "Oscuro",
    "This feature is unavailable due to encryption settings.": "Esta característica no está disponible debido a la configuración de cifrado.",
    "Enable plugins": "Habilitar plugins",
    "Enable document protection for": "Habilitar la protección de documentos para",
    "All users": "Todos los usuarios",
    "Owner only": "Solo propietario"
},
"nplurals=2; plural=(n != 1);");
