OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "アクセスが拒否されました",
    "Invalid request" : "リクエストが不正です",
    "Files not found" : "ファイルが見つかりません",
    "File not found" : "ファイルが見つかりません",
    "Not permitted" : "権限がありません",
    "Download failed" : "ダウンロードできませんでした",
    "The required folder was not found" : "開こうとしたフォルダーがありません",
    "You don't have enough permission to create": "作成権限がありません",
    "Template not found" : "テンプレートが見つかりません",
    "Can't create file" : "ファイルを作成できません",
    "Format is not supported" : "このフォーマットはサポートされていません",
    "Conversion is not required" : "変換する必要はありません",
    "Failed to download converted file": "変換されたファイルをダウンロードできませんでした",
    "ONLYOFFICE app is not configured. Please contact admin" : "ONLYOFFICEアプリが設定されていません。管理者に相談してください",
    "FileId is empty" : "ファイルIDが空です",
    "You do not have enough permissions to view the file": "ファイルを閲覧する権限ありません",
    "Error occurred in the document service" : "ドキュメントサービスでエラーが発生しました",
    "Not supported version": "サポートされていないバージョン",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICEに接続できません。管理者に相談してください",
    "Loading, please wait." : "読み込み中です...。しばらくお待ちください。",
    "File created": "ファイルが作成されました",
    "Open in ONLYOFFICE" : "ONLYOFFICEで開く",
    "Convert with ONLYOFFICE" : "ONLYOFFICEで変換",
    "Document" : "ドキュメント",
    "Spreadsheet" : "スプレッドシート",
    "Presentation" : "プレゼンテーション",
    "Error when trying to connect" : "接続時にエラーが発生しました",
    "Settings have been successfully updated" : "設定が更新されました",
    "Server can't read xml" : "サーバーでxmlを読み込ませんでした",
    "Bad Response. Errors: " : "不正なレスポンス エラー: ",
    "Documentation" : "ドキュメンテーション",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "ONLYOFFICE Docs の位置は、ドキュメントサービスがインストールされているサーバーのアドレスを指定します。以下の行の'<documentserver>'をサーバーアドレスに変更してください。",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "暗号化アプリが有効になっていますから、アプリをご使用できません。マスターキーを有効にすると、アプリの作業をご続行できます。",
    "ONLYOFFICE Docs address": "ONLYOFFICE Docs アドレス",
    "Advanced server settings": "サーバー詳細設定",
    "ONLYOFFICE Docs address for internal requests from the server": "サーバーから内部リクエストに利用されるONLYOFFICE Docs アドレス",
    "Server address for internal requests from ONLYOFFICE Docs": "ONLYOFFICE Docsから内部リクエストに利用されるサーバーアドレス",
    "Secret key (leave blank to disable)" : "シークレットキー (ブランクで無効)",
    "Open file in the same tab" : "ファイルを同じタブで開く",
    "The default application for opening the format": "以下のファイルフォーマットをデフォルトで開く",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "編集できるファイルフォーマット (フォーマットの制限により、以下のフォーマットを保存する時にデータが失われる可能性があります)",
    "View details" : "詳細表示",
    "Save" : "保存",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "アクティブコンテンツの混在は許可されていません。ONLYOFFICE DocsにはHTTPSアドレスが必要です",
    "Restrict access to editors to following groups": "エディターの利用を以下のグループに制限する",
    "review" : "レビュー",
    "form filling" : "フォーム入力",
    "comment" : "コメント",
    "custom filter" : "ユーザー設定フィルター",
    "download" : "ダウンロード",
    "Server settings" : "サーバー設定",
    "Common settings" : "共通設定",
    "Editor customization settings" : "エディターカスタム設定",
    "The customization section allows personalizing the editor interface": "エディターインターフェイスのカスタマイズ",
    "Display Chat menu button": "チャットメニューボタンを表示する",
    "Display the header more compact": "ヘッダーをよりコンパクトに表示する",
    "Display Feedback & Support menu button": "フィードバックとサポートメニューボタンを表示する",
    "Display Help menu button": "ヘルプメニューボタンを表示する",
    "Display monochrome toolbar header": "ツールバーヘッダーをモノクロで表示する",
    "Save as" : "別名で保存",
    "File saved" : "ファイルが保存されました",
    "Insert image" : "画像を挿入",
    "Select recipients" : "受取者を選択",
    "Connect to demo ONLYOFFICE Docs server" : "ONLYOFFICE Docsのデモサーバーに接続する",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period.": "これはパブリックテストサーバーです。プライベートな機密データには使用しないでください。サーバーを30日間、利用できます。",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "30日間のテスト期間が終了したら、ONLYOFFICE Docs デモサーバーには繋がらなくなります。",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "パブリック ONLYOFFICE Docs サーバーを使っているので、プライベートな機密データを利用しないようにしてください。",
    "Select file to compare" : "比較するファイルを選択",
    "Review mode for viewing": "レビューモード時の表示方式",
    "Markup": "マークアップ",
    "Final": "最終版",
    "Original": "オリジナル",
    "version": "バージョン",
    "Disable certificate verification (insecure)": "証明書の検証を無効にする（安全ではありません)",
    "Keep intermediate versions when editing (forcesave)": "編集時に、中間バージョンを保持する (強制保存)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "ONLYOFFICEを使用してドキュメントのサムネールを生成する(ディスク容量を消費します)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "編集されたドキュメントの各バージョンのメタデータを保持する(ディスク容量を消費します)",
    "Clear": "消去",
    "All history successfully deleted": "すべての履歴が正常に削除されました",
    "Create": "作成",
    "Select template" : "テンプレートを選択する",
    "Invalid file provided": "提供されたファイルは無効です",
    "Empty": "空",
    "Error" : "エラー",
    "Add a new template": "新しいテンプレートを追加する:",
    "Template already exists": "テンプレートは既に存在しています",
    "Template must be in OOXML format": "テンプレートはOOXML形式である必要があります",
    "Template successfully added": "テンプレートが正常に追加されました",
    "Template successfully deleted": "テンプレートが正常に削除されました",
    "Common templates": "よく使われるテンプレート",
    "Failed to delete template": "テンプレートを削除できませんでした",
    "File has been converted. Its content might look different.": "ファイルが変換されました。 その内容は異なって見えるかもしれません。",
    "Download as": "別の形式でダウンロード",
    "Download": "ダウンロード",
    "Origin format": "オリジンの形式",
    "Failed to send notification": "通知を送信できませんでした",
    "Notification sent successfully": "通知を送信しました",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s は あなたを %2\$s: \"%3\$s\"に記載されました。",
    "Choose a format to convert {fileName}": "{fileName}を変換する形式を選択してください",
    "Form template": "フォーム テンプレート",
    "Form template from existing text file": "既存のテキストファイルからフォームテンプレートを作成する",
    "Create form": "フォームの作成",
    "Fill in form in ONLYOFFICE": "ONLYOFFICEでフォームを記入する",
    "Create new Form template": "新しいフォームテンプレートの作成",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "オンラインで入力可能なフォームを作成するには、ONLYOFFICE Docs 7.0版まで更新してください",
    "Security": "セキュリティ",
    "Run document macros": "ドキュメントマクロを実行する",
    "Default editor theme": "エディターのデフォルトテーマ",
    "Light": "明るい",
    "Classic Light": "ライト(クラシック)",
    "Dark": "ダーク",
    "This feature is unavailable due to encryption settings.": "この機能は暗号化の設定により使用できません。",
    "Enable plugins": "プラグインを有効にする",
    "Enable document protection for": "次のユーザーに対して文書の保護機能を有効にする",
    "All users": "すべてのユーザー",
    "Owner only": "所有者のみ"
},
"nplurals=1; plural=0;");
