<div id="{dialog_name}" class="onlyoffice-download-container" title="{dialog_title}">
    <p></p>
    <select id="onlyoffice-download-select">
        <option data-value=""></option>
    </select>
</div>