OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Nekad åtkomst",
    "Invalid request" : "Ogiltig förfrågan",
    "Files not found" : "Filer som inte hittades",
    "File not found" : "Filen hittades inte",
    "Not permitted" : "Inte tillåten",
    "Download failed" : "Nedladdning misslyckades",
    "The required folder was not found" : "Den nödvandiga mappen hittades inte",
    "You don't have enough permission to create" : "Du har inte tillräcklig behörighet att skapa",
    "Template not found" : "Mallen hittades inte",
    "Can't create file" : "Kan inte skapa filen",
    "Format is not supported" : "Formatet stöds inte",
    "Conversion is not required" : "Konvertering är inte nödvändig",
    "Failed to download converted file" : "Misslyckades ladda ner konverterad fil",
    "ONLYOFFICE app is not configured. Please contact admin" : "ONLYOFFICE-appen är inte aktiverad. Kontakta systemadministratören",
    "FileId is empty" : "Fil-ID är tomt",
    "You do not have enough permissions to view the file" : "Du har inte tillräcklig behörighet för att visa filen",
    "Error occurred in the document service" : "Ett fel uppstod i dokumenttjänsten",
    "Not supported version" : "Ej supportad version",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICE inte nåbar.  Kontakta systemadministratören",
    "Loading, please wait." : "Laddar... var god vänta.",
    "File created" : "Filen skapad",
    "Open in ONLYOFFICE" : "Öppna i ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Konvertera med ONLYOFFICE",
    "Document" : "Dokument",
    "Spreadsheet" : "Kalkylblad",
    "Presentation" : "Presentation",
    "Error when trying to connect" : "Fel vid försök att ansluta",
    "Settings have been successfully updated" : "Inställningarna har uppdaterats",
    "Server can't read xml" : "Servern kan inte läsa XML",
    "Bad Response. Errors: " : "Felaktigt svar. Fel:",
    "Documentation" : "Dokumentation",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "ONLYOFFICE Docs plats specificerar adressen till servern där ONLYOFFICE är installerad. Ändra '<dokumentserver>' till serverns adress i nedanstående rad.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Krypteringsapp är aktiverad, programmet kan inte fungera. Du kan fortsätta arbeta med programmet om du aktiverar huvudnyckeln.",
    "ONLYOFFICE Docs address" : "Adress till ONLYOFFICE Docs",
    "Advanced server settings" : "Avancerade serverinställningar",
    "ONLYOFFICE Docs address for internal requests from the server" : "Adress till ONLYOFFICE Docs för interna förfragningar från servern",
    "Server address for internal requests from ONLYOFFICE Docs" : "Serveradress för interna förfrågningar från ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Hemlig nyckel (lämna blank för att inaktivera)",
    "Open file in the same tab" : "Öppna dokument i samma flik",
    "The default application for opening the format" : "Standardprogram for att öppna format",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Öppna filen för redigering (på grund av formatrestriktioner kan data gå förlorade när du sparar i format från listan nedan)",
    "View details" : "Visa detaljer",
    "Save" : "Spara",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Blandat aktivt innehåll är inte tillåtet. HTTPS-adress till ONLYOFFICE Docs krävs.",
    "Restrict access to editors to following groups" : "Begränsa åtkomst till följande grupper",
    "review" : "granska",
    "form filling" : "formulärfyllning",
    "comment" : "kommentar",
    "custom filter" : "anpassat filter",
    "download" : "ladda ner",
    "Server settings" : "Serverinställningar",
    "Common settings" : "Allmänna inställningar",
    "Editor customization settings" : "Anpassningar ONLYOFFICE ",
    "The customization section allows personalizing the editor interface" : "Denna del tillåter anpassningar av redigeringsgränssnittet",
    "Display Chat menu button" : "Visa chatt",
    "Display the header more compact" : "Visa kompakt sidhuvud",
    "Display Feedback & Support menu button" : "Visa Feedback & Support i menyn",
    "Display Help menu button" : "Visa hjälp i menyn",
    "Display monochrome toolbar header" : "Visa svartvit verktygsfältshuvud",
    "Save as" : "Spara som",
    "File saved" : "Filen har sparats",
    "Insert image" : "Infoga bild",
    "Select recipients" : "Välj mottagare",
    "Connect to demo ONLYOFFICE Docs server" : "Anslut till demo ONLYOFFICE Docsserver",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Detta är en offentlig testserver, använd den inte för privat känslig information. Servern kommer att finnas tillgänglig under en 30-dagarsperiod.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "När 30-dagars testperioden är över, kan du inte längre ansluta till demo ONLYOFFICE Docsserver.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Du använder en offentlig demo ONLYOFFICE Docsserver. Lagra inte privat känslig information.",
    "Select file to compare" : "Välj fil att jämföra",
    "Review mode for viewing": "Granskningsläge för visning",
    "Markup": "Markering",
    "Final": "Slutgiltig",
    "Original": "Ursprunglig",
    "version": "verzia",
    "Disable certificate verification (insecure)": "Använd inte certifikatsverifiering (osäkert)",
    "Keep intermediate versions when editing (forcesave)": "Behåll mellanliggande versioner vid redigering (tvinga att spara)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Använd ONLYOFFICE för att generera en förhandsgranskning av dokument (detta använder diskutrymme)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Behåll metadata för varje version när dokumentet redigeras (detta använder diskutrymme) ",
    "Clear": "Rensa",
    "All history successfully deleted": "All historik har tagits bort",
    "Create": "Skapa",
    "Select template" : "Välj mall",
    "Invalid file provided" : "Ogiltig fil tillhandahölls",
    "Empty": "Tom",
    "Error" : "Fel",
    "Add a new template": "Lägg till en ny mall",
    "Template already exists": "Mallen finns redan",
    "Template must be in OOXML format": "Mallen måste vara i OOXML-format",
    "Template successfully added": "Mallen lades till",
    "Template successfully deleted": "Mallen har tagits bort",
    "Common templates": "Delade mallar",
    "Failed to delete template": "Det gick inte att ta bort mallen",
    "File has been converted. Its content might look different.": "Filen har konverterats. Dess innehåll kan se annorlunda ut.",
    "Download as": "Ladda ned som",
    "Download": "Ladda ned",
    "Origin format": "Ursprungsformat",
    "Failed to send notification": "Det gick inte att skicka aviseringen",
    "Notification sent successfully": "Aviseringen har skickats",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s nämnde dig i %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Välj det filformat som {fileName} ska konverteras till.",
    "Form template": "Formulärmall",
    "Form template from existing text file": "Formulärmall från befintlig textfil",
    "Create form": "Skapa formulär",
    "Fill in form in ONLYOFFICE": "Fylla i formulär i ONLYOFFICE",
    "Create new Form template": "Skapa ny formulärmall",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Uppdatera ONLYOFFICE Docs till version 7.0 för att arbeta med ifyllbart onlineformulär",
    "Security": "Säkerhet",
    "Light": "Ljus",
    "Classic Light": "Klassiskt ljus",
    "Dark": "Mörk"
},
"nplurals=2; plural=(n != 1);");
