OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Accès refusé",
    "Invalid request" : "Requête invalide",
    "Files not found" : "Fichiers introuvables",
    "File not found" : "Fichier introuvable",
    "Not permitted" : "Non autorisé",
    "Download failed" : "Echec du téléchargement",
    "The required folder was not found" : "Le dossier requis n'a pas été trouvé",
    "You don't have enough permission to create" : "Vous n'avez pas la permission de créer",
    "Template not found" : "Modèle introuvable",
    "Can't create file" : "Le fichier ne peut pas être créé",
    "Format is not supported" : "Format non supporté",
    "Conversion is not required" : "Conversion non requise",
    "Failed to download converted file" : "Echec du téléchargement du fichier converti",
    "ONLYOFFICE app is not configured. Please contact admin" : "L'application ONLYOFFICE n'est pas configuré. Veuillez contacter votre administrateur",
    "FileId is empty" : "FileId est vide",
    "You do not have enough permissions to view the file" : "Vous n'avez pas la permission de voir le fichier",
    "Error occurred in the document service" : "Une erreur s'est produite dans le service de document",
    "Not supported version" : "Version non supportée",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICE est indisponible. Veuillez contacter votre administrateur",
    "Loading, please wait." : "Chargement, veuillez patienter.",
    "File created" : "Fichier créé",
    "Open in ONLYOFFICE" : "Ouvrir dans ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Convertir avec ONLYOFFICE",
    "Document" : "Document",
    "Spreadsheet" : "Feuille de calcul",
    "Presentation" : "Présentation",
    "Error when trying to connect" : "Erreur durant la tentative de connexion",
    "Settings have been successfully updated" : "Les paramètres ont été mis à jour avec succès",
    "Server can't read xml" : "Le serveur ne peut pas lire le XML",
    "Bad Response. Errors: " : "Mauvaise réponse. Erreurs:",
    "Documentation" : "Documentation",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "L'emplacement du ONLYOFFICE Docs désigne l'adresse du serveur sur lequel est installé le service de document. Veuillez modifier le '<documentserver>' avec l'adresse du serveur de service de document dans la ligne ci-dessous",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "L'application de chiffrement est activée, ONLYOFFICE ne peut pas fonctionner. Vous pouvez continuer à travailler avec ONLYOFFICE si vous activez la clé principale (master key)",
    "ONLYOFFICE Docs address" : "Adresse du ONLYOFFICE Docs",
    "Advanced server settings" : "Paramètres avancés du serveur",
    "ONLYOFFICE Docs address for internal requests from the server" : "Adresse du ONLYOFFICE Docs pour les demandes internes du serveur",
    "Server address for internal requests from ONLYOFFICE Docs" : "Adresse du serveur pour les demandes internes du ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Clé secrète (laisser vide pour désactiver)",
    "Open file in the same tab" : "Ouvrir le fichier dans le même onglet",
    "The default application for opening the format" : "Application par défaut pour ouvrir le format",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Ouvrir le fichier pour édition (en raison de restrictions de format, des données peuvent être perdues lors de l'enregistrement dans les formats de la liste ci-dessous)",
    "View details" : "Voir les détails",
    "Save" : "Enregistrer",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Le contenu mixte actif n'est pas autorisé. Une adresse HTTPS pour le ONLYOFFICE Docs est requise",
    "Restrict access to editors to following groups" : "Restreindre l'accès aux  éditeurs pour les groupes suivants",
    "review" : "révision",
    "form filling" : "remplissage de formulaire",
    "comment" : "commentaire",
    "custom filter" : "filtre personnalisé",
    "download" : "télécharger",
    "Server settings" : "Paramètres du serveur",
    "Common settings" : "Paramètres communs",
    "Editor customization settings" : "Paramètres de personnalisation de l'éditeur",
    "The customization section allows personalizing the editor interface" : "La section de personnalisation permet de personnaliser l'interface de l'éditeur",
    "Display Chat menu button" : "Afficher le bouton du menu du chat",
    "Display the header more compact" : "Afficher l'en-tête plus compact",
    "Display Feedback & Support menu button" : "Afficher le bouton du menu 'Feedback & Support'",
    "Display Help menu button" : "Afficher le bouton du menu 'Aide'",
    "Display monochrome toolbar header" : "Afficher un en-tête monochrome de la barre d'outils",
    "Save as" : "Enregistrer sous",
    "File saved" : "Le fichier a été enregistré",
    "Insert image" : "Insérer une image",
    "Select recipients" : "Sélectionner les destinataires",
    "Connect to demo ONLYOFFICE Docs server" : "Se connecter à la version démo de ONLYOFFICE Docs",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "C’est un serveur public proposé à des fins de tests, veuillez ne pas l’utiliser pour vos données personnelles sensibles. Le serveur est disponible pendant 30 jours.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "La période d’essai de 30 jours est expirée, vous n’êtes plus en mesure de vous connecter à la version démo de ONLYOFFICE Docs.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Vous utilisez la version démo de ONLYOFFICE Docs, proposée à des fins de tests. Veuillez ne pas stocker vos données confidentielles.",
    "Select file to compare" : "Sélectionner fichier à comparer",
    "Review mode for viewing": "Mode révision lors de l’affichage",
    "Markup": "Balisage",
    "Final": "Finale",
    "Original": "Original",
    "version": "version",
    "Disable certificate verification (insecure)": "Désactiver la vérification du certificat (non sur)",
    "Keep intermediate versions when editing (forcesave)": "Sauvegarder les versions intermédiaires lors de l'édition (enregistrement obligatoire)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Utilisez ONLYOFFICE pour générer l'aperçu du document (occupe de l'espace disque)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Gardez les métadonnées pour chaque version dès que le document est modifié (occupe de l'espace disque)",
    "Clear": "Effacer",
    "All history successfully deleted": "L'historique a été supprimé avec succès",
    "Create": "Créer",
    "Select template" : "Sélectionnez un modèle",
    "Invalid file provided" : "Fichier non valide",
    "Empty": "Vide",
    "Error" : "Erreur",
    "Add a new template": "Ajouter un nouveau modèle",
    "Template already exists": "Le modèle existe déjà",
    "Template must be in OOXML format": "Le modèle doit être au format OOXML",
    "Template successfully added": "Le modèle a été ajouté avec succès",
    "Template successfully deleted": "Le modèle a été supprimé avec succès",
    "Common templates": "Modèles communs",
    "Failed to delete template": "Impossible de supprimer le modèle",
    "File has been converted. Its content might look different.": "Le fichier a été converti. Son contenu peut s'afficher différemment.",
    "Download as": "Télécharger sous",
    "Download": "Télécharger",
    "Origin format": "Format d’origin",
    "Failed to send notification": "Échec de l’envoi de la notification",
    "Notification sent successfully": "Notification a été envoyée avec succès",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s vous a mentionné dans %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Choisissez un format à convertir {fileName}",
    "Form template": "Modèle de formulaire",
    "Form template from existing text file": "Modèle de formulaire à partir d'un fichier texte existant",
    "Create form": "Créer un formulaire",
    "Fill in form in ONLYOFFICE": "Remplir le formulaire dans ONLYOFFICE",
    "Create new Form template": "Créer un nouveau modèle de formulaire",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Veuillez mettre à jour ONLYOFFICE Docs vers la version 7.0 pour travailler sur les formulaires à remplir en ligne",
    "Security": "Sécurité",
    "Run document macros": "Exécuter des macros de documents",
    "Default editor theme": "Thème d'éditeur par défaut",
    "Light": "Clair",
    "Classic Light": "Classique clair",
    "Dark": "Sombre",
    "This feature is unavailable due to encryption settings.": "Cette fonctionnalité n'est pas disponible en raison des paramètres de chiffrement.",
    "Enable plugins": "Activer les plugins",
    "Enable document protection for": "Activer la protection des documents par mot de passe pour",
    "All users": "Tous les utilisateurs",
    "Owner only": "Propriétaire uniquement"
},
"nplurals=2; plural=(n > 1);");
