OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Zugriff verweigern",
    "Invalid request" : "Ungültige Anfrage",
    "Files not found" : "Dateien nicht gefunden",
    "File not found" : "Datei nicht gefunden",
    "Not permitted" : "Nicht erlaubt",
    "Download failed" : "Download fehlgeschlagen",
    "The required folder was not found" : "Der gewünschte Ordner wurde nicht gefunden",
    "You don't have enough permission to create" : "Sie haben nicht genug Berechtigung zum Erstellen",
    "Template not found" : "Vorlage nicht gefunden",
    "Can't create file" : "Datei kann nicht erstellt werden",
    "Format is not supported" : "Dateiformat wird nicht unterstützt",
    "Conversion is not required" : "Umsetzung ist nicht erforderlich",
    "Failed to download converted file" : "Fehler beim Herunterladen der konvertierten Datei",
    "ONLYOFFICE app is not configured. Please contact admin" : "ONLYOFFICE App ist nicht konfiguriert. Bitte wenden Sie sich an Ihren Administrator",
    "FileId is empty" : "Datei-ID ist leer",
    "You do not have enough permissions to view the file" : "Sie haben nicht genug Berechtigungen zum Ansehen der Datei",
    "Error occurred in the document service" : "Im Dokumentenservice ist ein Fehler aufgetreten",
    "Not supported version" : "Nicht unterstützte Version",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICE ist zurzeit nicht erreichbar.  Bitte wenden Sie sich an Ihren Administrator",
    "Loading, please wait." : "Laden... Bitte warten.",
    "File created" : "Erstellte Datei",
    "Open in ONLYOFFICE" : "In ONLYOFFICE öffnen",
    "Convert with ONLYOFFICE" : "Mit ONLYOFFICE umwandeln",
    "Document" : "Dokument",
    "Spreadsheet" : "Tabelle",
    "Presentation" : "Präsentation",
    "Error when trying to connect" : "Fehler beim Anschließen",
    "Settings have been successfully updated" : "Einstellungen wurden erfolgreich aktualisiert",
    "Server can't read xml" : "Server kann eine xml-Datei nicht einlesen",
    "Bad Response. Errors: " : "Bad Response. Fehler:",
    "Documentation" : "Dokumentation",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "ONLYOFFICE Docsstandort gibt die Adresse des Servers mit den installierten Dokumentdiensten an. Bitte ändern Sie '<documenterver>' für die Serveradresse in der folgenden Zeile.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "App Verschlüsselung ist aktiviert. Die Anwendung kann nicht funktionieren. Sie können mit der Anwendung weiterarbeiten, wenn Sie den Hauptschlüssel aktivieren.",
    "ONLYOFFICE Docs address" : "Die Adresse von ONLYOFFICE Docs",
    "Advanced server settings" : "Erweiterte Servereinstellungen",
    "ONLYOFFICE Docs address for internal requests from the server" : "Die Adresse von ONLYOFFICE Docs für interne Anforderungen vom Server",
    "Server address for internal requests from ONLYOFFICE Docs" : "Serveradresse für interne Anforderungen vom ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Geheimer Schlüssel (freilassen, um zu deaktivieren)",
    "Open file in the same tab" : "Datei in der gleichen Registerkarte öffnen",
    "The default application for opening the format" : "Die Standardanwendung zum Öffnen des Formats",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Öffnen Sie die Datei zum Bearbeiten (aufgrund von Formateinschränkungen können die Daten beim Speichern in den Formaten aus der folgenden Liste verloren gehen)",
    "View details" : "Details anzeigen",
    "Save" : "Speichern",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Mixed Active Content ist nicht möglich. HTTPS-Adresse für ONLYOFFICE Docs ist erforderlich.",
    "Restrict access to editors to following groups" : "Den Zugriff auf Editoren auf folgende Gruppen gewähren",
    "review" : "review",
    "form filling" : "ausfüllen von formularen",
    "comment" : "kommentarе",
    "custom filter" : "benutzerdefinierter filter",
    "download" : "herunterladen",
    "Server settings" : "Servereinstellungen",
    "Common settings" : "Allgemeine Einstellungen",
    "Editor customization settings" : "Editor-Einstellungen",
    "The customization section allows personalizing the editor interface" : "Die Anpassungssektion ermöglicht die Anpassung der Editoroberfläche",
    "Display Chat menu button" : "Chat-Taste anzeigen",
    "Display the header more compact" : "Kompakten Header anzeigen",
    "Display Feedback & Support menu button" : "Feedback-& Support-Taste anzeigen",
    "Display Help menu button" : "Hilfetaste anzeigen",
    "Display monochrome toolbar header" : "Monochromen Kopfbereich der Symbolleiste anzeigen",
    "Save as" : "Speichern als",
    "File saved" : "Datei wurde gespeichert",
    "Insert image" : "Bild einfügen",
    "Select recipients" : "Empfänger auswählen",
    "Connect to demo ONLYOFFICE Docs server" : "Verbindung zu Demo ONLYOFFICE Docs Server herstellen",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Dies ist ein öffentlicher Testserver. Bitte verwenden Sie beim Testen keine privaten sensiblen Daten. Der Server ist 30 Tage lang verfügbar.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "Der 30-tägige Testzeitraum ist abgelaufen. Sie können keine Verbindung mehr zu Demo ONLYOFFICE Docs Server herstellen.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Sie verwenden den öffentlichen Demo ONLYOFFICE Docs Server. Bitte benutzen Sie ihn nicht zum Speichern von Ihren privaten sensiblen Daten.",
    "Select file to compare" : "Datei zum Vergleich auswählen",
    "Review mode for viewing": "Review-Modus zum Anzeigen",
    "Markup": "Markup",
    "Final": "Endgültig",
    "Original": "Original",
    "version": "version",
    "Disable certificate verification (insecure)": "Zertifikatsüberprüfung deaktivieren (unsicher)",
    "Keep intermediate versions when editing (forcesave)": "Zwischenversionen bei der Bearbeitung aufbewahren (force save)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "ONLYOFFICE verwenden, um eine Dokumentvorschau zu erstellen (Speicherplatz erforderlich)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Metadaten für jede Version beim Bearbeiten des Dokuments aufbewahren (Speicherplatz erforderlich)",
    "Clear": "Leeren",
    "All history successfully deleted": "Gesamtverlauf wurde erfolgreich gelöscht",
    "Create": "Erstellen",
    "Select template" : "Vorlage auswählen",
    "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
    "Empty": "Leer",
    "Error" : "Fehler",
    "Add a new template": "Neue Vorlage hinzufügen",
    "Template already exists": "Vorlage ist bereits vorhanden",
    "Template must be in OOXML format": "Vorlage soll im OOXML-Format sein",
    "Template successfully added": "Vorlage wurde erfolgreich hinzugefügt",
    "Template successfully deleted": "Vorlage wurde erfolgreich entfernt",
    "Common templates": "Gemeinsame Vorlagen",
    "Failed to delete template": "Fehler beim Löschen einer Vorlage",
    "File has been converted. Its content might look different.": "Die Datei wurde konvertiert. Der Inhalt könnte anders aussehen.",
    "Download as": "Herunterladen als",
    "Download": "Herunterladen",
    "Origin format": "Ursprüngliches Format",
    "Failed to send notification": "Fehler beim Senden einer Benachrichtigung",
    "Notification sent successfully": "Benachrichtigung erfolgreich gesendet",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s hat dich in %2\$s erwähnt: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Wählen Sie das Format für {fileName} aus",
    "Form template": "Formularvorlage",
    "Form template from existing text file": "Formularvorlage aus Textdatei",
    "Create form": "Formular erstellen",
    "Fill in form in ONLYOFFICE": "Formular in ONLYOFFICE ausfüllen",
    "Create new Form template": "Neue Formularvorlage erstellen",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Für Online-Arbeit mit Formularen ist Version 7.0 von ONLYOFFICE Docs erforderlich",
    "Security": "Sicherheit",
    "Run document macros": "Makros im Dokument ausführen",
    "Default editor theme": "Standardmäßiges Thema des Editors",
    "Light": "Hell",
    "Classic Light": "Klassisch Hell",
    "Dark": "Dunkel",
    "This feature is unavailable due to encryption settings.": "Diese Funktion ist wegen der Verschlüsselungseinstellungen nicht verfügbar",
    "Enable plugins": "Arbeit mit Plugins aktivieren",
    "Enable document protection for": "Hinzufügen von Passwörtern in Dokumenten aktivieren für",
    "All users": "Alle Benutzer",
    "Owner only": "Nur Besitzer"
},
"nplurals=2; plural=(n != 1);");
