OC.L10N.register(
    "onlyoffice",
    {
    "Access denied": "Accés denegat",
    "Invalid request": "Sol·licitud invàlida",
    "Files not found": "Arxius no trobats",
    "File not found": "Arxiu no trobat",
    "Not permitted": "No permès",
    "Download failed": "Error en la descàrrega",
    "The required folder was not found": "No s'ha trobat la carpeta necessària",
    "You don't have enough permission to create": "No té suficient permís per a crear",
    "Template not found": "Plantilla no trobada",
    "Can't create file": "No es pot crear l'arxiu",
    "Format is not supported": "Format no suportat",
    "Conversion is not required": "No es requereix conversió",
    "Failed to download converted file": "Fallada en la descàrrega de l'arxiu convertit",
    "ONLYOFFICE app is not configured. Please contact admin": "Aplicació ONLYOFFICE no està configurada. Si us plau, contacti amb l'administrador",
    "FileId is empty": "Id de l'arxiu és buit",
    "You do not have enough permissions to view the file": "No té suficients permisos per a veure l'arxiu",
    "Error occurred in the document service": "S'ha produït un error en el servei de documents",
    "Not supported version": "Versió no compatible",
    "ONLYOFFICE cannot be reached. Please contact admin": "No es pot accedir a l'ONLYOFFICE. Si us plau, contacti amb l'administrador",
    "Loading, please wait.": "Carregant, esperi, si us plau.",
    "File created": "Arxiu creat",
    "Open in ONLYOFFICE": "Obrir en ONLYOFFICE",
    "Convert with ONLYOFFICE": "Convertir amb ONLYOFFICE",
    "Document": "Document",
    "Spreadsheet": "Full de càlcul",
    "Presentation": "Presentació",
    "Error when trying to connect": "Error en intentar establir la connexió",
    "Settings have been successfully updated": "Ajustos han estat actualitzats amb èxit",
    "Server can't read xml": "Servidor no pot llegir xml",
    "Bad Response. Errors: ": "Resposta Dolenta. Errors:",
    "Documentation": "Documentació",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line.": "Ubicació de l'ONLYOFFICE Docs especifica la direcció del servidor amb els serveis de documents instal·lats. Si us plau, canviï '<documentserver>' per a la direcció de servidor en la línia inferior.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "",
    "ONLYOFFICE Docs address" : "Direcció d'ONLYOFFICE Docs",
    "Advanced server settings" : "Ajustos de servidor avançats",
    "ONLYOFFICE Docs address for internal requests from the server" : "Direcció d'ONLYOFFICE Docs per a sol·licituds internes del servidor",
    "Server address for internal requests from ONLYOFFICE Docs" : "Direcció de servidor per a sol·licituds internes de l'ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Clau secreta (deixi en blanc o desactivi)",
    "Open file in the same tab" : "Obrir arxiu en la mateixa pestanya",
    "The default application for opening the format" : "L'aplicació predeterminada per a obrir el format",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Obrir arxiu per a editar (a causa de les restriccions de format les dades podrien perdre's en guardar en els formats de la següent llista)",
    "View details" : "Veure detalls",
    "Save" : "Guardar",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Contingut Mixt Actiu no està permès. Es requereix la direcció HTTPS per a ONLYOFFICE Docs.",
    "Restrict access to editors to following groups" : "Restringir l'accés a editors a següents grups",
    "review" : "",
    "form filling" : "",
    "comment" : "",
    "custom filter" : "",
    "download" : "",
    "Server settings" : "Ajustos de servidor",
    "Common settings" : "Ajustos comuns",
    "Editor customization settings" : "Ajustos de l'editor",
    "The customization section allows personalizing the editor interface" : "La secció de personalització permet personalitzar la interfície de l'editor",
    "Display Chat menu button" : "Mostrar el botó de Xat",
    "Display the header more compact" : "Mostrar l'encapçalat més compacte",
    "Display Feedback & Support menu button" : "Mostrar el botó de Feedback i Suport",
    "Display Help menu button" : "Mostrar el botó d'Ajuda",
    "Display monochrome toolbar header" : "Mostrar l'encapçalat monocromàtic de la barra d'eines",
    "Save as" : "Guardar com",
    "File saved" : "L'arxiu ha estat desat",
    "Insert image" : "Inserir imatge",
    "Select recipients" : "Seleccionar destinataris",
    "Connect to demo ONLYOFFICE Docs server" : "Connectar-se al servidor de ONLYOFFICE Docs de demostració",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Aquest és un servidor de proves públic, si us plau no l'usis per a les teves dades confidencials. El servidor estarà disponible durant un període de 30 dies.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "El període de prova de 30 dies ha acabat, ja no pots connectar-te al servidor d'ONLYOFFICE Docs de demostració.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Estàs fent servir el servidor d'ONLYOFFICE Docs de demostració. Si us plau, no emmagatzemis les teves dades confidencials aquí.",
    "Select file to compare" : "Seleccioni un arxiu per comparar",
    "Review mode for viewing": "Mode de revisió per visualització",
    "Markup": "Canvis",
    "Final": "Final",
    "Original": "Original",
    "version": "versió",
    "Disable certificate verification (insecure)": "Desactivar la verificació de certificats (insegur)",
    "Keep intermediate versions when editing (forcesave)": "Mantenir les versions intermèdies durant l'edició (forçar guardar)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Usar ONLYOFFICE per a generar una vista prèvia del document (ocuparà espai en el disc)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Guardar les metadades de cada versió en editar el document (ocuparà espai en el disc)",
    "Clear": "Suprimeix",
    "All history successfully deleted": "Tot l'historial s'ha eliminat correctament",
    "Create": "Crear",
    "Select template" : "Seleccionar plantilla",
    "Invalid file provided" : "Arxiu proporcionat no vàlid",
    "Empty": "Buit",
    "Error" : "Error",
    "Add a new template": "Afegir una plantilla nova",
    "Template already exists": "La plantilla ja existeix",
    "Template must be in OOXML format": "La plantilla ha de tenir el format OOXML",
    "Template successfully added": "La plantilla es va agregar correctament",
    "Template successfully deleted": "La plantilla es va eliminar correctament",
    "Common templates": "Plantilles comunes",
    "Failed to delete template": "No es va poder eliminar la plantilla",
    "File has been converted. Its content might look different.": "L'arxiu s'ha convertit. El seu contingut pot ser diferent.",
    "Download as": "Descarregar com",
    "Download": "Descarregar",
    "Origin format": "Format original",
    "Failed to send notification": "Error en enviar la notificació",
    "Notification sent successfully": "Notificació enviada correctament",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s ha esmentat en %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Triï un format per a convertir {fileName}",
    "Form template": "Plantilla de formulari",
    "Form template from existing text file": "Plantilla de formulari d'un fitxer de text existent",
    "Create form": "Crear formulari",
    "Fill in form in ONLYOFFICE": "Omplir el formulari en ONLYOFFICE",
    "Create new Form template": "Crear nova plantilla de formulari",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Si us plau, actualitzi ONLYOFFICE Docs a la versió 7.0 per a poder treballar amb formularis emplenables en línia",
    "Security": "Seguretat",
    "Light": "Llum",
    "Classic Light": "Llum clàssica",
    "Dark": "Fosc"
},
"nplurals=2; plural=(n != 1);");