OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Отказан достъп",
    "Invalid request" : "Неправилна заявка",
    "Files not found" : "Файловете не са намерени",
    "File not found" : "Файлът не открит",
    "Not permitted" : "Операцията не е разрешена",
    "Download failed" : "Грешка при изтегляне",
    "The required folder was not found" : "Папката не е намерена",
    "You don't have enough permission to create" : "Нямате права за създаване",
    "Template not found" : "Шаблона не е намерен",
    "Can't create file" : "Файла не може да бъде създаден",
    "Format is not supported" : "Форматът не се поддържа",
    "Conversion is not required" : "Не е необходимо конвертиране",
    "Failed to download converted file" : "Грешка при изтегляне на конверирания файл",
    "ONLYOFFICE app is not configured. Please contact admin" : "Приложението ONLYOFFICE не конфигурирано. Моля, свържете се с администратора",
    "FileId is empty" : "Полето е празно",
    "You do not have enough permissions to view the file" : "Нямате достатъчно права за преглед на файла",
    "Error occurred in the document service" : "Възникна грешка в услугата за документи",
    "Not supported version" : "Неподдържана версия",
    "ONLYOFFICE cannot be reached. Please contact admin" : "Приложението ONLYOFFICE не е достъпно. Моля, свържете се с администратора",
    "Loading, please wait." : "Зареждане. Моля, изчакайте.",
    "File created" : "Файлът е създаден",
    "Open in ONLYOFFICE" : "Отвори в ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Конвертирай с ONLYOFFICE",
    "Document" : "Документ",
    "Spreadsheet" : "Електронна таблица",
    "Presentation" : "Презентация",
    "Error when trying to connect" : "Грешка при опит за свързване",
    "Settings have been successfully updated" : "Настройките са успешно обновени",
    "Server can't read xml" : "Невъзможно прочитане на xml файла на сървъра",
    "Bad Response. Errors: " : "Неправилен отговор. Грешки:",
    "Documentation" : "Документация",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "Адреса на ONLYOFFICE Docs определя адреса на сървъра с инсталирани услуги за документи. Моля, променете '<documentserver>' адреса на сървъра в долния ред.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Активирано е криптиране, приложението не може да продължи работа. Ще може да продължите работа с приложението, ако използвате Основен ключ.",
    "ONLYOFFICE Docs address" : "Адрес на ONLYOFFICE Docs",
    "Advanced server settings" : "Допълнителни настройки на сървъра",
    "ONLYOFFICE Docs address for internal requests from the server" : "Адрес на ONLYOFFICE Docs за вътрешни заявки към сървъра",
    "Server address for internal requests from ONLYOFFICE Docs" : "Адрес на сървъра за вътрешни заявки на ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Секретен ключ (оставете празно за забрана)",
    "Open file in the same tab" : "Отваряне на файла в същия прозорец",
    "The default application for opening the format" : "Приложение по подразбиране за отваряне на следните формати",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Отваряне на файла за редактиране (според ограниченята на формата данните могат да бъдат загубени при запис във формати от списъка по-долу)",
    "View details" : "Виж детайли",
    "Save" : "Запази",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Смесеното активно съдържание е недопустимо. За ONLYOFFICE Docs е необходимо използването на HTTPS-адрес.",
    "Restrict access to editors to following groups" : "Разреши достъп до редакторите само за тези групи",
    "review" : "преглед",
    "form filling" : "попълване на формуляр",
    "comment" : "коментар",
    "custom filter" : "персонализиран филтър",
    "download" : "изтегли",
    "Server settings" : "Настройки на сървъра",
    "Common settings" : "Общи настройки",
    "Editor customization settings" : "Персонализиращи настройки на редактора",
    "The customization section allows personalizing the editor interface" : "Разделът за персонализация позволява персонализиране на редакторския интерфейс",
    "Display Chat menu button" : "Бутон за показване на Чат",
    "Display the header more compact" : "По-компактно показване на заглавната част",
    "Display Feedback & Support menu button" : "Показване на бутоните за Обратна връзка и Поддръжка",
    "Display Help menu button" : "Показване на бутон за меню Помощ",
    "Display monochrome toolbar header" : "Показване на монохромна заглавна лента с инструменти",
    "Save as" : "Запази като",
    "File saved" : "Файлът е запазен",
    "Insert image" : "Вмъкване на изображение",
    "Select recipients" : "Изберете получатели",
    "Connect to demo ONLYOFFICE Docs server" : "Свързване с демо ONLYOFFICE Docs сървър",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Това е обществен тестов сървър, моля, не използвайте за чувствителни частни данни. Сървърът ще е на разположение по време на 30-дневния период.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "30-дневният тестов период приключи, вече не можете да се свържете с демо ONLYOFFICE Docs сървър.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Използвате обществения демо ONLYOFFICE Docs сървър. Моля, не съхранявайте чувствителни частни данни на него.",
    "Select file to compare" : "Изберете файл за сравнение",
    "Review mode for viewing": "Режим на преглед за преглеждане",
    "Markup": "Маркиране",
    "Final": "Последни",
    "Original": "Оригинални",
    "version": "версия",
    "Disable certificate verification (insecure)": "Деактивиране на проверката на сертификата (несигурно)",
    "Keep intermediate versions when editing (forcesave)": "Съхранявайте междинни версии при редактиране (force save)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Използвайте ONLYOFFICE, за да генерирате преглед на документа (ще заеме дисково пространство)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Запазете метаданните за всяка версия, щом документът бъде редактиран (ще заеме дисково пространство)",
    "Clear": "Изчисти",
    "All history successfully deleted": "Цялата история е успешно изтрита",
    "Create": "Създай",
    "Select template" : "Избор на шаблон",
    "Invalid file provided" : "Предоставен е невалиден файл",
    "Empty": "Празно",
    "Error" : "Грешка",
    "Add a new template": "Добавяне на шаблон",
    "Template already exists": "Шаблонът вече съществува",
    "Template must be in OOXML format": "Шаблонът трябва да е във формат OOXML",
    "Template successfully added": "Шаблонът е добавен успешно",
    "Template successfully deleted": "Шаблонът е изтрит успешно",
    "Common templates": "Често срещани шаблони",
    "Failed to delete template": "Неуспешно изтриване на шаблон",
    "File has been converted. Its content might look different.": "Файлът бе преобразуван. Съдържанието му може да изглежда различно.",
    "Download as": "Изтегли като",
    "Download": "Изтегли",
    "Origin format": "Формат на произход",
    "Failed to send notification": "Неуспешно изпращане на известие",
    "Notification sent successfully": "Успешно изпратено известие",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s, Ви спомена във %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Изберете формат за конвертиране {fileName}",
    "Form template": "Шаблон на формуляр",
    "Form template from existing text file": "Шаблон на формуляр от съществуващ текстов файл",
    "Create form": "Създайте формуляр",
    "Fill in form in ONLYOFFICE": "Попълнете формуляр в ONLYOFFICE",
    "Create new Form template": "Създайте нов шаблон на формуляр",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Молим да актуализирате ONLYOFFICE Docs към версия 7.0, за да работи с онлайн формуляри за попълване",
    "Security": "Сигурност",
    "Light": "Светла",
    "Classic Light": "Класически светла",
    "Dark": "Тъмна"
},
"nplurals=2; plural=(n != 1);");
