OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Acesso negado",
    "Invalid request" : "Solicitação inválida",
    "Files not found" : "Arquivos não encontrados",
    "File not found" : "Arquivo não encontrado",
    "Not permitted" : "Não permitido",
    "Download failed" : "Baixar arquivo falhou",
    "The required folder was not found" : "A pasta requisitada não foi encontrada",
    "You don't have enough permission to create" : "Você não tem permissões suficientes para criar",
    "Template not found" : "Modelo não encontrado",
    "Can't create file" : "Não é possível criar o arquivo",
    "Format is not supported" : "Formato não suportado",
    "Conversion is not required" : "Não é necessário converter",
    "Failed to download converted file" : "Falha ao baixar arquivo convertido",
    "ONLYOFFICE app is not configured. Please contact admin" : "Aplicação ONLYOFFICE não está configurada. Favor contatar o administrador",
    "FileId is empty" : "FileId (ID de arquivo) está vazio",
    "You do not have enough permissions to view the file" : "Você não tem permissões suficientes para ver o arquivo",
    "Error occurred in the document service" : "Ocorreu um erro no serviço de documentos",
    "Not supported version" : "Versão não suportada",
    "ONLYOFFICE cannot be reached. Please contact admin" : "Não foi possível conectar ao ONLYOFFICE. Favor contatar o administrador.",
    "Loading, please wait." : "Carregando, por favor aguarde.",
    "File created" : "Arquivo criado",
    "Open in ONLYOFFICE" : "Abrir no ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Converta com ONLYOFFICE",
    "Document" : "Documento",
    "Spreadsheet" : "Planilha",
    "Presentation" : "Apresentação",
    "Error when trying to connect" : "Erro ao tentar conectar",
    "Settings have been successfully updated" : "Configurações salvas com sucesso",
    "Server can't read xml" : "Servidor não pode ler xml",
    "Bad Response. Errors: " : "Resposta ruim. Erros:",
    "Documentation" : "Documentação",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "O Endereço do ONLYOFFICE Docs especifica o servidor onde o serviço de documentos está instalado.\nPor favor mude '<documentserver>' para o endereço do servidor na linha abaixo.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "A criptografia de arquivos está ativada, este aplicativo não pode operar. Ative a chave mestre se quiser continuar trabalhando.",
    "ONLYOFFICE Docs address" : "Endereço do ONLYOFFICE Docs",
    "Advanced server settings" : "Configurações avançadas do servidor",
    "ONLYOFFICE Docs address for internal requests from the server" : "Endereço do ONLYOFFICE Docs para pedidos internos do servidor",
    "Server address for internal requests from ONLYOFFICE Docs" : "Endereço do servidor para pedidos internos do ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Chave secreta (deixe em branco para desativar)",
    "Open file in the same tab" : "Abrir arquivo na mesma aba",
    "The default application for opening the format" : "Aplicação padrão para os formatos",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Habilitar edição (devido à restrição dos formatos, dados podem ser perdidos ao salvar nos formatos abaixo)",
    "View details" : "Ver detalhes",
    "Save" : "Salvar",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Conteúdo Misto não é permitido. É necessário um endereço HTTPS para o ONLYOFFICE Docs.",
    "Restrict access to editors to following groups" : "Acesso apenas para os seguintes grupos",
    "review" : "revisar",
    "form filling" : "preenchimento de formularios",
    "comment" : "comente",
    "custom filter" : "filtro personalizado",
    "download" : "baixar",
    "Server settings" : "Configurações do servidor",
    "Common settings" : "Configurações comuns",
    "Editor customization settings" : "Configurações de personalização do editor",
    "The customization section allows personalizing the editor interface" : "Seção de customização permite personalizar a interface do editor",
    "Display Chat menu button" : "Exibir o botão do menu do bate-papo",
    "Display the header more compact" : "Exibir o cabeçalho mais compacto",
    "Display Feedback & Support menu button" : "Exibir o botão do menu de feedback e suporte",
    "Display Help menu button" : "Exibir o botão do menu Ajuda",
    "Display monochrome toolbar header" : "Exibir cabeçalho da barra de ferramentas monocromático",
    "Save as" : "Salvar como",
    "File saved" : "O arquivo foi salvo",
    "Insert image" : "Inserir imagem",
    "Select recipients" : "Selecione os destinatários",
    "Connect to demo ONLYOFFICE Docs server" : "Conectar ao Servidor de demonstração do ONLYOFFICE Docs",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Este é um servidor de teste público, não o use para dados confidenciais. O servidor estará disponível por um período de 30 dias.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "O período de teste de 30 dias acabou, você não pode mais se conectar ao Servidor de demonstração do ONLYOFFICE Docs",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Você está usando o Servidor de demonstração pública. Não armazene dados confidenciais.",
    "Select file to compare" : "Selecionar arquivo para comparar",
    "Review mode for viewing": "Modo de revisão para visualização",
    "Markup": "Markup",
    "Final": "Final",
    "Original": "Original",
    "version": "versão",
    "Disable certificate verification (insecure)": "Desativar a verificação do certificado (inseguro)",
    "Keep intermediate versions when editing (forcesave)": "Manter versões intermediárias ao editar (forçar salvar)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Usar ONLYOFFICE para gerar uma visualização do documento (ocupará espaço em disco)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Manter os metadados para cada versão após a edição (ocupará espaço em disco)  (ocupará espaço em disco)",
    "Clear": "Limpar",
    "All history successfully deleted": "O histórico foi excluído com sucesso",
    "Create": "Criar",
    "Select template" : "Selecionar um modelo",
    "Invalid file provided" : "Arquivo fornecido inválido",
    "Empty": "Vazio",
    "Error" : "Erro",
    "Add a new template": "Adicionar um novo modelo",
    "Template already exists": "Modelo já existe",
    "Template must be in OOXML format": "Modelo deve estar no formato OOXML",
    "Template successfully added": "Modelo adicionado com sucesso",
    "Template successfully deleted": "Modelo excluído com sucesso",
    "Common templates": "Modelos comuns",
    "Failed to delete template": "Falha ao excluir modelo",
    "File has been converted. Its content might look different.": "O arquivo foi convertido. Seu conteúdo pode ser diferente.",
    "Download as": "Baixar como",
    "Download": "Baixar",
    "Origin format": "Formato de origem",
    "Failed to send notification": "Falha ao enviar notificação",
    "Notification sent successfully": "Notificação enviada com sucesso",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s mencionado você em %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Escolha um formato para converter {fileName}",
    "Form template": "Modelo de formulário",
    "Form template from existing text file": "Modelo de formulário a partir de arquivo de texto existente",
    "Create form": "Criar formulário",
    "Fill in form in ONLYOFFICE": "Preencher formulário no ONLYOFFICE",
    "Create new Form template": "Criar novo modelo de Formulário",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Atualize o ONLYOFFICE Docs para a versão 7.0 para trabalhar em formulários preenchíveis online",
    "Security": "Segurança",
    "Light": "Claro",
    "Classic Light": "Clássico claro",
    "Dark": "Escuro",
    "Enable plugins": "Ativar plug-ins",
    "Enable document protection for": "Ativar proteção de documento para",
    "All users": "Todos os usuários",
    "Owner only": "Somente proprietário"
},
"nplurals=2; plural=(n > 1);");
