OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Toegang geweigerd",
    "Invalid request": "Ongeldig verzoek",
    "Files not found": "Bestanden niet gevonden",
    "File not found": "Bestand niet gevonden",
    "Not permitted": "Niet toegestaan",
    "Download failed": "Download mislukt",
    "The required folder was not found": "De vereiste map is niet gevonden",
    "You don't have enough permission to create": "U heeft geen voldoende aanmaak rechten",
    "Template not found": "Sjabloon niet gevonden",
    "Can't create file": "Kan bestand niet aanmaken",
    "Format is not supported": "Formaat wordt niet ondersteund",
    "Conversion is not required": "Converteren is niet vereist",
    "Failed to download converted file": "Kan geconverteerd bestand niet downloaden",
    "ONLYOFFICE app is not configured. Please contact admin": "ONLYOFFICE app is niet geconfigureerd. Neem contact op met de admin",
    "FileId is empty": "FileId is leeg",
    "You do not have enough permissions to view the file": "U heeft niet genoeg rechten om het bestand te bekijken",
    "Error occurred in the document service": "Er is een fout opgetreden in de documentservice",
    "Not supported version": "Niet ondersteunde versie",
    "ONLYOFFICE cannot be reached. Please contact admin": "ONLYOFFICE kan niet worden bereikt. Neem contact op met de admin",
    "Loading, please wait.": "Laden, wacht alstublieft.",
    "File created": "Bestand Aangemaakt",
    "Open in ONLYOFFICE": "Open in ONLYOFFICE",
    "Convert with ONLYOFFICE": "Converteer met ONLYOFFICE",
    "Document": "Document",
    "Spreadsheet": "Werkblad",
    "Presentation": "Presentaties",
    "Error when trying to connect": "Fout bij het verbinden",
    "Settings have been successfully updated": "Instellingen zijn met succes bijgewerkt",
    "Server can't read xml": "Server kan xml niet lezen",
    "Bad Response. Errors: ": "Slechte Reactie. Fouten",
    "Documentation": "Documentatie",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line.": "ONLYOFFICE Docs Location geeft het adres op van de server waarop de documentdiensten geïnstalleerd zijn. Verander de '<documentserver>' voor het serveradres in de onderstaande regel.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key.": "Encryptie-app is ingeschakeld, de applicatie werkt niet. U kunt blijven werken met de applicatie als u de hoofdsleutel inschakelt.",
    "ONLYOFFICE Docs address": "ONLYOFFICE Docs adres",
    "Advanced server settings": "Geavanceerde serverinstellingen",
    "ONLYOFFICE Docs address for internal requests from the server": "Adres van de ONLYOFFICE Docs voor interne verzoeken van de server",
    "Server address for internal requests from ONLYOFFICE Docs": "Serveradres voor interne verzoeken van de ONLYOFFICE Docs",
    "Secret key (leave blank to disable)": "Geheime sleutel (leeg laten om niet te te gebruiken)",
    "Open file in the same tab": "Bestand in dezelfde tabblad openen",
    "The default application for opening the format": "De standaardtoepassing voor het openen van het formaat",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)": "Open het bestand om het te bewerken (wegens formaatbeperkingen kunnen de gegevens verloren gaan bij het opslaan in de formaten van de onderstaande lijst)",
    "View details": "Bekijk details",
    "Save": "Opslaan",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required.": "Gemende Actieve Inhoud is niet toegestaan. HTTPS-adres voor ONLYOFFICE Docs is vereist.",
    "Restrict access to editors to following groups": "Beperk de toegang tot editors tot de volgende groepen",
    "review": "overzicht",
    "form filling": "formulier invullen",
    "comment": "opmerking",
    "custom filter": "aangepast filter",
    "download": "downloaden",
    "Server settings": "Serverinstellingen",
    "Common settings": "Algemene instellingen",
    "Editor customization settings": "Editor aanpassingsinstellingen",
    "The customization section allows personalizing the editor interface": "Met de aanpassingssectie kunt u de interface van de editor personaliseren",
    "Display Chat menu button": "Chat Menuknop weergeven",
    "Display the header more compact": "De koptekst compacter weergeven",
    "Display Feedback & Support menu button": "Menuknop Terugkoppeling & Ondersteuning weergeven",
    "Display Help menu button": "Menuknop Help weergeven",
    "Display monochrome toolbar header": "Toon de monochrome koptekst van de werkbalk",
    "Save as": "Opslaan als",
    "File saved": "Bestand opgeslagen",
    "Insert image": "Afbeelding invoegen",
    "Select recipients": "Kies ontvangers",
    "Connect to demo ONLYOFFICE Docs server": "Verbinden met de demo ONLYOFFICE Docs server",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period.": "Dit is een openbare testserver, gelieve deze niet te gebruiken voor persoonlijke en vertrouwelijke gegevens. De server zal gedurende een periode van 30 dagen beschikbaar zijn.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server.": "De 30-dagen proefperiode is voorbij, u kunt niet langer verbinding maken met demo ONLYOFFICE Docs server.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data.": "U gebruikt de openbare demo ONLYOFFICE Docs server. Sla geen vertrouwelijke gegevens op.",
    "Select file to compare": "Kies het bestand dat u wilt vergelijken",
    "Review mode for viewing": "Beoordelingsmodus voor bekijken",
    "Markup": "Markup",
    "Final": "Einde",
    "Original": "Origineel",
    "version": "versie",
    "Disable certificate verification (insecure)": "Verificatie van certificaten uitschakelen (onveilig)",
    "Keep intermediate versions when editing (forcesave)": "Bewaar tussentijdse versies bij bewerken (forcesave)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Gebruik ONLYOFFICE om een voorbeeld van een document te genereren (dit neemt schijfruimte in beslag)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Bewaar metadata voor elke versie zodra het document bewerkt is (dit neemt schijfruimte in beslag)",
    "Clear": "Wissen",
    "All history successfully deleted": "Alle geschiedenis met succes gewist",
    "Create": "Maak",
    "Select template": "Kies een sjabloon",
    "Invalid file provided": "Ongeldig bestand opgegeven",
    "Empty": "Leeg",
    "Error": "Fout",
    "Add a new template": "Voeg een nieuw sjabloon toe",
    "Template already exists": "Sjabloon bestaat al",
    "Template must be in OOXML format": "Sjabloon moet in OOXML formaat zijn",
    "Template successfully added": "Sjabloon met succes toegevoegd",
    "Template successfully deleted": "Sjabloon met succes verwijderd",
    "Common templates": "Algemene Sjablonen",
    "Failed to delete template": "Sjabloon verwijderen mislukt",
    "File has been converted. Its content might look different.": "Het bestand is geconverteerd. De inhoud kan er anders uitzien.",
    "Download as": "Downloaden als",
    "Download": "Downloaden",
    "Origin format": "Oorsprong formaat",
    "Failed to send notification": "Kennisgeving niet verzonden",
    "Notification sent successfully": "Kennisgeving succesvol verzonden",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s genoemd in de %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Kies een formaat om {fileName} te converteren",
    "Form template": "Formulier sjabloon",
    "Form template from existing text file": "Formulier sjabloon uit bestaand tekstbestand",
    "Create form": "Formulier maken",
    "Fill in form in ONLYOFFICE": "Formulier invullen in ONLYOFFICE",
    "Create new Form template": "Nieuw Formulier sjabloon maken",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Update ONLYOFFICE Docs naar versie 7.0 om online invulbare formulieren te kunnen gebruiken",
    "Security": "Beveiliging",
    "Run document macros": "Document macro's uitvoeren",
    "Default editor theme": "Standaard editor thema",
    "Light": "Licht",
    "Classic Light": "Klassiek Licht",
    "Dark": "Donker"
},
"nplurals=2; plural=(n != 1);");
