OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "禁止访问",
    "Invalid request" : "非法请求",
    "Files not found" : "文件未找到",
    "File not found" : "文件未找到",
    "Not permitted" : "没有权限",
    "Download failed" : "下载失败",
    "The required folder was not found" : "必须的文件夹未找到",
    "You don't have enough permission to create" : "没有足够权限创建文件",
    "Template not found" : "模板未找到",
    "Can't create file" : "无法创建文件",
    "Format is not supported" : "文件格式不支持",
    "Conversion is not required" : "无需文件转换",
    "Failed to download converted file" : "转换后的文件下载失败",
    "ONLYOFFICE app is not configured. Please contact admin" : "ONLYOFFICE未配置，请联系管理员。",
    "FileId is empty" : "文件ID为空",
    "You do not have enough permissions to view the file" : "您没有足够权限浏览该文件",
    "Error occurred in the document service" : "文档服务内部发生异常",
    "Not supported version" : "不支持的版本",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICE服务器无法连接，请联系管理员。",
    "Loading, please wait." : "载入中，请稍后...",
    "File created" : "文件已创建",
    "Open in ONLYOFFICE" : "用 ONLYOFFICE 打开",
    "Convert with ONLYOFFICE" : "用 ONLYOFFICE 转换",
    "Document" : "文档",
    "Spreadsheet" : "电子表格",
    "Presentation" : "演示文稿",
    "Error when trying to connect" : "连接是发生异常",
    "Settings have been successfully updated" : "设置已保存",
    "Server can't read xml" : "服务器无法读取XML",
    "Bad Response. Errors: " : "错误的返回: ",
    "Documentation" : "文档集",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "ONLYOFFICE Docs 位置指定了安装了文档服务的服务器的地址，请将'<documentserver>'改为下面一行中的服务器地址。",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "加密应用程序已启用，应用程序无法工作。如果启用主密钥，则可以继续使用该应用程序。",
    "ONLYOFFICE Docs address" : "ONLYOFFICE Docs地址",
    "Advanced server settings" : "更多设置",
    "ONLYOFFICE Docs address for internal requests from the server" : "用于服务器内部的ONLYOFFICE Docs的地址",
    "Server address for internal requests from ONLYOFFICE Docs" : "用于ONLYOFFICE Docs内部请求的服务器的地址",
    "Secret key (leave blank to disable)" : "秘钥(留空为关闭)",
    "Open file in the same tab" : "在相同的切签中打开",
    "The default application for opening the format": "默认关联的文件格式",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "默认的文件编辑器 (由于文件格式限制，保存为下列格式时，数据可能会缺失)",
    "View details" : "查看详情",
    "Save" : "保存",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "不允许混合活动内容，请使用HTTPS连接ONLYOFFICE Docs。",
    "Restrict access to editors to following groups" : "仅授权的用户组可以使用该服务",
    "review" : "审阅",
    "form filling" : "表单填报",
    "comment" : "评论",
    "custom filter" : "自定义筛选器",
    "download" : "下载",
    "Server settings" : "服务器设置",
    "Common settings" : "常用设置",
    "Editor customization settings" : "编辑器自定义设置",
    "The customization section allows personalizing the editor interface": "自定义设置区允许对编辑器界面进行个性化设置",
    "Display Chat menu button" : "显示交流菜单按钮",
    "Display the header more compact" : "更紧致的显示菜单栏",
    "Display Feedback & Support menu button" : "显示反馈&支持菜单按钮",
    "Display Help menu button" : "显示帮助菜单按钮",
    "Display monochrome toolbar header" : "显示单色工具栏标题",
    "Save as" : "另存为",
    "File saved" : "文件已保存",
    "Insert image" : "插入图片",
    "Select recipients" : "选择接收者",
    "Connect to demo ONLYOFFICE Docs server" : "连接到 ONLYOFFICE Docs 服务器的演示",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "这是公开的测试服务器，请勿用于隐私数据。服务器试用期限为30天。",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "30天试用期已结束，无法连接ONLYOFFICE Docs 服务器的演示。",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "您正在使用公开ONLYOFFICE Docs服务器的演示，请勿存储隐私数据。",
    "Select file to compare" : "选择文件比较",
    "Review mode for viewing": "审阅模式浏览",
    "Markup": "修订",
    "Final": "最终版",
    "Original": "原始版本",
    "version": "版本",
    "Disable certificate verification (insecure)": "关闭证书校验(不安全)",
    "Keep intermediate versions when editing (forcesave)": "编辑时保留中间版本 (强制保存)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "使用ONLYOFFICE生成文档预览（将占用磁盘空间）",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "编辑文档后保留每个版本的元数据（它将占用磁盘空间）",
    "Clear": "清除",
    "All history successfully deleted": "所有历史记录成功删除",
    "Create": "创建",
    "Select template" : "选择模板",
    "Invalid file provided" : "提供了无效文件",
    "Empty": "空",
    "Error" : "错误",
    "Add a new template": "添加一个新的模板",
    "Template already exists": "模板已经存在",
    "Template must be in OOXML format": "模板必须是OOXML格式",
    "Template successfully added": "模板成功添加",
    "Template successfully deleted": "模板成功删除",
    "Common templates": "通用模板",
    "Failed to delete template": "删除模板失败",
    "File has been converted. Its content might look different.": "文件已被转换。其内容可能看起来有所不同。",
    "Download as": "下载为",
    "Download": "下载",
    "Origin format": "原产地格式",
    "Failed to send notification": "发送通知失败",
    "Notification sent successfully": "通知发送成功",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s 在 %2\$s: \"%3\$s\"中提到了您.",
    "Choose a format to convert {fileName}": "选择要转换{fileName}的格式",
    "Form template": "表单模板",
    "Form template from existing text file": "用现有的文本文件创建模板",
    "Create form": "创建表单",
    "Fill in form in ONLYOFFICE": "在ONLYOFFICE上填写表单",
    "Create new Form template": "创建新的表单模板",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "请将ONLYOFFICE Docs更新到7.0版本，以便在线编辑可填写的表单",
    "Security": "安全",
    "Default editor theme": "编辑器默认的主题",
    "Light": "光",
    "Classic Light": "经典浅色",
    "Dark": "黑暗的",
    "This feature is unavailable due to encryption settings.": "由于加密设置，该功能不可用。",
    "Enable plugins": "启用插件",
    "Enable document protection for": "为以下用户启用文档保护",
    "All users": "所有用户",
    "Owner only": "仅限所有者"
},
"nplurals=1; plural=0;");
