OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Accesso negato",
    "Invalid request" : "Richiesta non valida",
    "Files not found" : "File non trovati",
    "File not found" : "File non trovato",
    "Not permitted" : "Non consentito",
    "Download failed" : "Download non riuscito",
    "The required folder was not found" : "La cartella richiesta non è stata trovata",
    "You don't have enough permission to create" : "Non hai sufficienti autorizzazioni per creare",
    "Template not found" : "Modello non trovato",
    "Can't create file" : "Non è possibile creare un file",
    "Format is not supported" : "Il formato non è supportato",
    "Conversion is not required" : "La conversione non è necessaria",
    "Failed to download converted file" : "Impossibile scaricare il file convertito",
    "ONLYOFFICE app is not configured. Please contact admin" : "L'applicazione ONLYOFFICE non è configurata. Si prega di contattare l'amministratore",
    "FileId is empty" : "Il campo è vuoto",
    "You do not have enough permissions to view the file" : "Non hai sufficienti autorizzazioni per visualizzare il file",
    "Error occurred in the document service" : "Si è verificato un errore nel servizio documenti",
    "Not supported version" : "Versione non supportata",
    "ONLYOFFICE cannot be reached. Please contact admin" : "Non è possibile raggiungere ONLYOFFICE. Si prega di contattare l'amministratore",
    "Loading, please wait." : "Caricamento in corso, attendere prego",
    "File created" : "File creato",
    "Open in ONLYOFFICE" : "Apri in ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Converti con ONLYOFFICE",
    "Document" : "Documento",
    "Spreadsheet" : "Foglio di calcolo",
    "Presentation" : "Presentazione",
    "Error when trying to connect" : "Errore durante il tentativo di connessione",
    "Settings have been successfully updated" : "Le impostazioni sono state aggiornate con successo",
    "Server can't read xml" : "Il server non può leggere xml",
    "Bad Response. Errors: " : "Risposta non corretta. Errori: ",
    "Documentation" : "Documentazione" ,
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "ONLYOFFICE Docs Location specifica l'indirizzo del server con i servizi documenti installati. Modifica il '<documentserver>' con l'indirizzo del server nella riga sottostante.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Encryption App è abilitata, l'applicazione non può funzionare. È possibile continuare a lavorare con l'applicazione se è abilitata la chiave master.",
    "ONLYOFFICE Docs address" : "Indirizzo di ONLYOFFICE Docs",
    "Advanced server settings" : "Impostazioni avanzate del server",
    "ONLYOFFICE Docs address for internal requests from the server" : "Indirizzo di ONLYOFFICE Docs per le richieste interne del server",
    "Server address for internal requests from ONLYOFFICE Docs" : "Indirizzo del server per le richieste interne da ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Chiave segreta (lasciare vuoto per disabilitare)",
    "Open file in the same tab" : "Apri il file nella stessa scheda",
    "The default application for opening the format": "L'applicazione predefinita per l'apertura del formato",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Apri il file per la modifica (a causa di restrizioni di formato, i dati potrebbero andare persi durante il salvataggio nei formati della lista sottostante)",
    "View details" : "Vedi dettagli",
    "Save" : "Salva",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Il contenuto attivo misto non è consentito. È richiesto l'indirizzo HTTPS per ONLYOFFICE Docs.",
    "Restrict access to editors to following groups" : "Limita l'accesso degli editor ai seguenti gruppi",
    "review" : "Revisione",
    "form filling" : "Compilare un modulo",
    "comment" : "Commento",
    "custom filter" : "Filtro personalizzato",
    "download" : "Scarica",
    "Server settings" : "Impostazioni del server",
    "Common settings" : "Impostazioni comuni",
    "Editor customization settings" : "Impostazioni di personalizzazione dell'editor",
    "The customization section allows personalizing the editor interface": "La sezione di personalizzazione permette di personalizzare l'interfaccia dell'editor",
    "Display Chat menu button" : "Pulsante del menu Mostra chat",
    "Display the header more compact" : "Mostra l'intestazione più compatta",
    "Display Feedback & Support menu button" : "Pulsante del menu Mostra feedback e supporto",
    "Display Help menu button" : "Pulsante del menu Mostra guida",
    "Display monochrome toolbar header" : "Visualizza intestazione della barra degli strumenti monocromatica",
    "Save as" : "Salva come",
    "File saved" : "File salvato",
    "Insert image" : "Inserisci l'immagine",
    "Select recipients" : "Seleziona i destinatari",
    "Connect to demo ONLYOFFICE Docs server" : "Collegati alla versione demo di ONLYOFFICE Docs",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period.": "Questo è un server di prova pubblico, non utilizzarlo per dati sensibili privati. Il server sarà disponibile per un periodo di 30 giorni.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "Il periodo di prova di 30 giorni è terminato; non è più possibile connettersi alla versione demo di ONLYOFFICE Docs.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Stai utilizzando la versione demo pubblica di ONLYOFFICE Docs. Non memorizzare dati sensibili privati.",
    "Select file to compare" : "Seleziona file da confrontare",
    "Review mode for viewing": "Modalità di revisione per la visualizzazione",
    "Markup": "Markup",
    "Final": "Finale",
    "Original": "Originale",
    "version": "versione",
    "Disable certificate verification (insecure)": "Disattiva la verifica del certificato (non sicuro)",
    "Keep intermediate versions when editing (forcesave)": "Mantieni le versioni intermedie durante la modifica (forzare salvataggio)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Usare ONLYOFFICE per generare anteprima documenti (occuperà spazio su disco)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Salvare metadati per ogni versione una volta modificato il documento (occuperà spazio su disco)",
    "Clear": "Svuota",
    "All history successfully deleted": "Cronologia eliminata con successo",
    "Create": "Crea",
    "Select template" : "Seleziona modello",
    "Invalid file provided" : "File fornito non valido",
    "Empty": "Vuoto",
    "Error" : "Errore",
    "Add a new template": "Aggiungi un nuovo modello",
    "Template already exists": "Modello già esiste",
    "Template must be in OOXML format": "Modello deve essere in formato OOXML",
    "Template successfully added": "Modello è stato aggiunto con successo",
    "Template successfully deleted": "Modello è stato cancellato con successo",
    "Common templates": "Modelli comuni",
    "Failed to delete template": "Impossibile eliminare il modello",
    "File has been converted. Its content might look different.": "Il file è stato convertito. Il suo contenuto potrebbe avere un aspetto diverso.",
    "Download as": "Scaricare come",
    "Download": "Scaricare",
    "Origin format": "Formato di origine",
    "Failed to send notification": "Invio di notifica non riuscito",
    "Notification sent successfully": "Notifica è stata inviata con successo",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s ti ha menzionato in %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Scegli un formato per convertire {fileName}",
    "Form template": "Modello di modulo",
    "Form template from existing text file": "Modello di modulo da file di testo esistente",
    "Create form": "Creare modulo",
    "Fill in form in ONLYOFFICE": "Compilare il modulo in ONLYOFFICE",
    "Create new Form template": "Creare un nuovo modello di modulo",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Si prega di aggiornare ONLYOFFICE Docs alla versione 7.0 per lavorare su moduli compilabili online",
    "Security": "Sicurezza",
    "Run document macros": "Esegui le macro del documento",
    "Default editor theme": "Tema dell'editor predefinito",
    "Light": "Chiaro",
    "Classic Light": "Classico chiaro",
    "Dark": "Scuro",
    "This feature is unavailable due to encryption settings.": "Questa funzionalità non è disponibile a causa delle impostazioni di crittografia.",
    "Enable plugins": "Abilitare plugin",
    "Enable document protection for": "Abilitare la protezione del documento per",
    "All users": "Tutti gli utenti",
    "Owner only": "Solo proprietario"
},
"nplurals=2; plural=(n != 1);");