OC.L10N.register(
    "onlyoffice",
    {
    "Access denied": "Adgang nægtet",
    "Invalid request": "Ugyldig anmodning",
    "Files not found": "Filer ikke fundet",
    "File not found": "Fil ikke fundet",
    "Not permitted": "Ikke tilladt",
    "Download failed": "Download fejlede",
    "The required folder was not found": "Den nødvendige mappe blev ikke fundet",
    "You don't have enough permission to create": "Du har ikke tilladelse nok til at oprette",
    "Template not found": "Skabelonen blev ikke fundet",
    "Can't create file": "Filen kan ikke oprettes",
    "Format is not supported": "Format er ikke understøttet",
    "Conversion is not required": "Konvertering er ikke påkrævet",
    "Failed to download converted file": "Kunne ikke downloade den konverterede fil",
    "ONLYOFFICE app is not configured. Please contact admin": "ONLYOFFICE-appen er ikke konfigureret. Kontakt venligst administrator",
    "FileId is empty": "Fil-ID er tom",
    "You do not have enough permissions to view the file": "Du har ikke tilstrækkelige tilladelser til at se filen",
    "Error occurred in the document service": "Der opstod en fejl i dokumenttjenesten",
    "Not supported version": "Ikke understøttet version",
    "ONLYOFFICE cannot be reached. Please contact admin": "ONLYOFFICE kan ikke nås. Kontakt venligst administrator",
    "Loading, please wait.": "Indlæser... vent venligst.",
    "File created": "Fil oprettet",
    "Open in ONLYOFFICE": "Åben i ONLYOFFICE",
    "Convert with ONLYOFFICE": "Konverter med ONLYOFFICE",
    "Document": "Dokument",
    "Spreadsheet": "Regneark",
    "Presentation": "Præsentation",
    "Error when trying to connect": "Fejl under forsøg på at oprette forbindelse",
    "Settings have been successfully updated": "Indstillingerne er blevet opdateret",
    "Server can't read xml": "Serveren kan ikke læse xml",
    "Bad Response. Errors: ": "Ingen respons. Fejl:",
    "Documentation": "Dokumentation",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line.": "ONLYOFFICE Docs Lokation angiver adressen på serveren med dokumenttjenesterne installeret. Skift venligst '<dokumentserver>' for serveradressen i linjen nedenfor.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key.": "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key.",
    "ONLYOFFICE Docs address": "ONLYOFFICE Docs-adresse",
    "Advanced server settings": "Avancerede serverindstillinger",
    "ONLYOFFICE Docs address for internal requests from the server": "ONLYOFFICE Docs-adresse for interne anmodninger fra serveren",
    "Server address for internal requests from ONLYOFFICE Docs": "Serveradresse for interne anmodninger fra ONLYOFFICE Docs",
    "Secret key (leave blank to disable)": "Hemmelig nøgle (lad være tom for at deaktivere)",
    "Open file in the same tab": "Åbn filen i samme fane",
    "The default application for opening the format": "Standardapplikationen til at åbne formatet",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)": "Åbn filen til redigering (på grund af formatbegrænsninger kan data gå tabt, når du gemmer i formaterne fra listen nedenfor)",
    "View details": "Se detaljer",
    "Save": "Gem",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required.": "Blandet aktivt indhold er ikke tilladt. HTTPS-adresse for ONLYOFFICE Docs er påkrævet.",
    "Restrict access to editors to following groups": "Begræns adgangen til redaktører til følgende grupper",
    "review": "Anmeldelse",
    "form filling": "Formular udfyldning",
    "comment": "Kommentar",
    "custom filter": "Brugerdefineret filter",
    "download": "Hent",
    "Server settings": "Serverindstillinger",
    "Common settings": "Fælles indstillinger",
    "Editor customization settings": "Editor tilpasningsindstillinger",
    "The customization section allows personalizing the editor interface": "Tilpasningssektionen gør det muligt at tilpasse editorgrænsefladen",
    "Display Chat menu button": "Vis chatmenuknap",
    "Display the header more compact": "Vis værktøjslinjen mere kompakt",
    "Display Feedback & Support menu button": "Vis feedback- og supportmenuknap",
    "Display Help menu button": "Vis menuknappen Hjælp",
    "Display monochrome toolbar header": "Vis monokrom værktøjslinje",
    "Save as": "Gem som",
    "File saved": "Filen er gemt",
    "Insert image": "Indsæt billede",
    "Select recipients": "Vælg modtagere",
    "Connect to demo ONLYOFFICE Docs server": "Opret forbindelse til demo ONLYOFFICE Docs-server",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period.": "Dette er en offentlig testserver, brug den venligst ikke til private følsomme data. Serveren vil være tilgængelig i en 30-dages periode.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server.": "30-dages testperioden er forbi, du kan ikke længere oprette forbindelse til demo ONLYOFFICE Docs-server.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data.": "Du bruger den offentlige demo ONLYOFFICE Docs-server. Gem venligst ikke private følsomme data.",
    "Select file to compare": "Vælg fil for at sammenligne",
    "Review mode for viewing": "Gennemgangstilstand for visning",
    "Markup": "Kladde",
    "Final": "Endelig",
    "Original": "Original",
    "version": "version",
    "Disable certificate verification (insecure)": "Deaktiver certifikatbekræftelse (usikker)",
    "Keep intermediate versions when editing (forcesave)": "Behold mellemversioner under redigering (tvangsgem)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Brug ONLYOFFICE til at generere et dokumenteksempel (...dette vil optage diskplads)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Gem metadata for hver version, når dokumentet er redigeret (...dette vil optage diskplads)",
    "Clear": "Klar",
    "All history successfully deleted": "Al historik blev slettet",
    "Create": "Opret",
    "Select template": "Vælg skabelon",
    "Invalid file provided": "Ugyldig fil angivet",
    "Empty": "Tom",
    "Error": "Fejl",
    "Add a new template": "Tilføj en ny skabelon",
    "Template already exists": "Skabelonen findes allerede",
    "Template must be in OOXML format": "Skabelonen skal være i OOXML-format",
    "Template successfully added": "Skabelon blev tilføjet",
    "Template successfully deleted": "Skabelonen blev slettet",
    "Common templates": "Fælles skabeloner",
    "Failed to delete template": "Skabelonen kunne ikke slettes",
    "File has been converted. Its content might look different.": "Filen er blevet konverteret. Dens indhold kan se anderledes ud.",
    "Download as": "Download som",
    "Download": "Hent",
    "Origin format": "Oprindelsesformat",
    "Failed to send notification": "Kunne ikke sende notifikation",
    "Notification sent successfully": "Meddelelse sendt",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s nævnt i %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Vælg et format til at konvertere {fileName}",
    "Form template": "Formularskabelon",
    "Form template from existing text file": "Formularskabelon fra eksisterende tekstfil",
    "Create form": "Opret formular",
    "Fill in form in ONLYOFFICE": "Udfyld formularen i ONLYOFFICE",
    "Create new Form template": "Opret ny formularskabelon",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Opdater venligst ONLYOFFICE Docs til version 7.0 for at arbejde på udfyldelige formularer online",
    "Security": "Sikkerhed",
    "Run document macros": "Kør dokumentmakroer",
    "Default editor theme": "Standard editortema",
    "Light": "Lys",
    "Classic Light": "Klassisk lys",
    "Dark": "Mørk",
    "This feature is unavailable due to encryption settings.": "Denne funktion er utilgængelig på grund af krypteringsindstillingerne"
},
"nplurals=2; plural=(n > 1);");
