OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Доступ запрещён",
    "Invalid request" : "Неправильный запрос",
    "Files not found" : "Файлы не найдены",
    "File not found" : "Файл не найден",
    "Not permitted" : "Операция запрещена",
    "Download failed" : "Ошибка скачивания",
    "The required folder was not found" : "Папка не найдена",
    "You don't have enough permission to create" : "У вас недостаточно прав на создание",
    "Template not found" : "Шаблон не найден",
    "Can't create file" : "Не удается создать файл",
    "Format is not supported" : "Формат не поддерживается",
    "Conversion is not required" : "Преобразование не требуется",
    "Failed to download converted file" : "Ошибка скачивания преобразованного файла",
    "ONLYOFFICE app is not configured. Please contact admin" : "Приложение ONLYOFFICE не сконфигурировано. Пожалуйста, свяжитесь с администратором",
    "FileId is empty" : "Поле пустое",
    "You do not have enough permissions to view the file" : "У вас недостаточно прав на просмотр файла",
    "Error occurred in the document service" : "Возникла ошибка в службе документов",
    "Not supported version" : "Неподдерживаемая версия",
    "ONLYOFFICE cannot be reached. Please contact admin" : "Приложение ONLYOFFICE недоступно. Пожалуйста, свяжитесь с администратором",
    "Loading, please wait." : "Загрузка. Пожалуйста, подождите.",
    "File created" : "Файл создан",
    "Open in ONLYOFFICE" : "Открыть в ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Конвертировать в ONLYOFFICE",
    "Document" : "Документ",
    "Spreadsheet" : "Электронная таблица",
    "Presentation" : "Презентация",
    "Error when trying to connect" : "При попытке соединения возникла ошибка",
    "Settings have been successfully updated" : "Настройки были успешно обновлены",
    "Server can't read xml" : "Невозможно прочитать xml файл на сервере",
    "Bad Response. Errors: " : "Неправильный ответ. Ошибки:",
    "Documentation" : "Документация",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "Расположение ONLYOFFICE Docs определяет адрес сервера с установлеными службами документов. Пожалуйста, замените '<documentserver>' в поле ниже на адрес сервера.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Включено шифрование, приложение не может продолжить работу. Вы сможете работать с приложением, если будете использовать мастер ключ.",
    "ONLYOFFICE Docs address" : "Адрес ONLYOFFICE Docs",
    "Advanced server settings" : "Дополнительные настройки сервера",
    "ONLYOFFICE Docs address for internal requests from the server" : "Адрес ONLYOFFICE Docs для внутренних запросов сервера",
    "Server address for internal requests from ONLYOFFICE Docs" : "Адрес сервера для внутренних запросов ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Секретный ключ (оставьте пустым для отключения)",
    "Open file in the same tab" : "Открыть файл в той же вкладке",
    "The default application for opening the format" : "Приложение по умолчанию для открытия формата",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Открыть файл на редактирование (из-за ограничений формата данные могут быть утеряны при сохранении в форматы из списка ниже)",
    "View details" : "Подробнее",
    "Save" : "Сохранить",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Смешанное активное содержимое запрещено. Для ONLYOFFICE Docs необходимо использовать HTTPS-адрес.",
    "Restrict access to editors to following groups" : "Дать доступ к редакторам только следующим группам",
    "review" : "рецензирование",
    "form filling" : "заполнение форм",
    "comment" : "комментирование",
    "custom filter" : "пользовательский фильтр",
    "download" : "скачивание",
    "Server settings" : "Настройки сервера",
    "Common settings" : "Общие настройки",
    "Editor customization settings" : "Настройка редактора",
    "The customization section allows personalizing the editor interface" : "Раздел настройки позволяет изменить интерфейс редактора",
    "Display Chat menu button" : "Отображать кнопку чата",
    "Display the header more compact" : "Отображать заголовок компактным",
    "Display Feedback & Support menu button" : "Отображать кнопку Обратной связи и поддержки",
    "Display Help menu button" : "Отображать кнопку справки",
    "Display monochrome toolbar header" : "Отображать монохромный заголовок панели инструментов",
    "Save as" : "Сохранить как",
    "File saved" : "Файл сохранён",
    "Insert image" : "Вставить изображение",
    "Select recipients" : "Выберите получателей",
    "Connect to demo ONLYOFFICE Docs server" : "Подключиться к демонстрационному серверу ONLYOFFICE Docs",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "Это публичный тестовый сервер, пожалуйста, не используйте его для личных конфиденциальных данных. Сервер будет доступен в течение 30 дней.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "30-дневный тестовый период закончен, вы больше не можете подключаться к демонстрационному серверу ONLYOFFICE Docs",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Вы используете публичный демонстрационный сервер ONLYOFFICE Docs. Пожалуйста, не храните конфиденциальные данные.",
    "Select file to compare" : "Выбрать файл для сравнения",
    "Review mode for viewing": "Режим рецензирования при просмотре",
    "Markup": "Изменения",
    "Final": "Изменённый документ",
    "Original": "Исходный документ",
    "version": "версия",
    "Disable certificate verification (insecure)": "Отключить проверку сертификата (небезопасно)",
    "Keep intermediate versions when editing (forcesave)": "Хранить промежуточные версии при редактировании (принудительное сохранение)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Использовать ONLYOFFICE для создания превью документа (займет место на диске)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Сохранять метаданные для каждой версии после редактирования (займет место на диске)",
    "Clear": "Очистить",
    "All history successfully deleted": "История успешно удалена",
    "Create": "Создать",
    "Select template" : "Выбрать шаблон",
    "Invalid file provided" : "Указан неправильный файл",
    "Empty": "Пустой",
    "Error" : "Ошибка",
    "Add a new template": "Добавить новый шаблон",
    "Template already exists": "Шаблон уже существует",
    "Template must be in OOXML format": "Шаблон должен быть в формате OOXML",
    "Template successfully added": "Шаблон успешно добавлен",
    "Template successfully deleted": "Шаблон успешно удален",
    "Common templates": "Общие шаблоны",
    "Failed to delete template": "Не удалось удалить шаблон",
    "File has been converted. Its content might look different.": "Файл был сконвертирован. Его форматирование могло измениться.",
    "Download as": "Скачать как",
    "Download": "Скачать",
    "Origin format": "Оригинальный формат",
    "Failed to send notification": "Ошибка отправки оповещения",
    "Notification sent successfully": "Оповещение успешно отправлено",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s упомянул вас в %2\$s: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Выберите формат для {fileName}",
    "Form template": "Шаблон формы",
    "Form template from existing text file": "Шаблон формы из существующего текстового файла",
    "Create form": "Создать форму",
    "Fill in form in ONLYOFFICE": "Заполнить форму в ONLYOFFICE",
    "Create new Form template": "Создать новый шаблон формы",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Обновите сервер ONLYOFFICE Docs до версии 7.0 для работы с формами онлайн",
    "Security": "Безопасность",
    "Run document macros": "Запускать макросы документа",
    "Default editor theme": "Тема редактора по умолчанию",
    "Light": "Светлая",
    "Classic Light": "Светлая классическая",
    "Dark": "Темная",
    "This feature is unavailable due to encryption settings.": "Данная функция недоступна из-за настроек шифрования",
    "Enable plugins": "Включить работу с плагинами",
    "Enable document protection for": "Включить возможность задавать пароль на документ для",
    "All users": "Всех пользователей",
    "Owner only": "Только владельцу"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
