OC.L10N.register(
    "onlyoffice",
    {
    "Access denied" : "Brak dostępu",
    "Invalid request" : "Niepoprawne zapytanie",
    "Files not found" : "Pliki nie znalezione",
    "File not found" : "Plik nie znaleziony",
    "Not permitted" : "Brak uprawnień",
    "Download failed" : "Pobieranie nie powiodło się",
    "The required folder was not found" : "Folder nie został znaleziony",
    "You don't have enough permission to create" : "Nie masz wystarczających uprawnień by utworzyć",
    "Template not found" : "Szablon nie znaleziony",
    "Can't create file" : "Nie można utworzyć pliku",
    "Format is not supported" : "Nieobsługiwany format",
    "Conversion is not required" : "Konwersja nie wymagana",
    "Failed to download converted file" : "Pobieranie konwertowanego pliku nie powiodło się",
    "ONLYOFFICE app is not configured. Please contact admin" : "OAplikacja ONLYOFFICE nie jest skonfigurowana. Skontaktuj się z administratorem",
    "FileId is empty" : "ID pliku jest puste",
    "You do not have enough permissions to view the file" : "Nie masz wystarczających uprawnień, aby wyświetlić plik",
    "Error occurred in the document service" : "Wystąpił błąd w usłudze dokumentów",
    "Not supported version" : "Nieobsługiwana wersja",
    "ONLYOFFICE cannot be reached. Please contact admin" : "ONLYOFFICE jest nieosiągalny. Skontaktuj się z administratorem",
    "Loading, please wait." : "Ładowanie, proszę czekać.",
    "File created" : "Plik utworzony",
    "Open in ONLYOFFICE" : "Otwórz w ONLYOFFICE",
    "Convert with ONLYOFFICE" : "Konwertuj",
    "Document" : "Nowy dokument",
    "Spreadsheet" : "Nowy skoroszyt",
    "Presentation" : "Nowa prezentacja",
    "Error when trying to connect" : "Błąd przy próbie połączenia",
    "Settings have been successfully updated" : "Ustawienia zaktualizowane pomyślnie",
    "Server can't read xml" : "Serwer nie może przeczytać xml",
    "Bad Response. Errors: " : "Zła odpowiedź. Błędy:",
    "Documentation" : "Dokumentacja",
    "ONLYOFFICE Docs Location specifies the address of the server with the document services installed. Please change the '<documentserver>' for the server address in the below line." : "Lokacja ONLYOFFICE Docs to adres serwera na którym Usługi Dokumentów są zainstalowe. Proszę zmienić '<documentserver>' na adres poniżej.",
    "Encryption App is enabled, the application cannot work. You can continue working with the application if you enable master key." : "Aplikacja nie działa, ponieważ włączone jest aplikacja Encryption App. Możesz kontynuować pracę z aplikacją, jeśli włączysz klucz master key.",
    "ONLYOFFICE Docs address" : "Adres ONLYOFFICE Docs",
    "Advanced server settings" : "Zaawansowane ustawienia serwera",
    "ONLYOFFICE Docs address for internal requests from the server" : "Adres ONLYOFFICE Docs dla zapytań wewnętrznych",
    "Server address for internal requests from ONLYOFFICE Docs" : "Adres serwera dla zapytań wewnętrznych z ONLYOFFICE Docs",
    "Secret key (leave blank to disable)" : "Klucz zabezpieczeń (pozostaw puste aby wyłączyć)",
    "Open file in the same tab" : "Otwórz plik w tym samym oknie",
    "The default application for opening the format" : "Domyślna aplikacja do otwierania formatów",
    "Open the file for editing (due to format restrictions, the data might be lost when saving to the formats from the list below)" : "Otwórz plik do edycji (ze względu na ograniczenia formatów, dane mogą zostac utracone przy zapisie do formatów podanych poniżej)",
    "View details" : "Szczegóły",
    "Save" : "Zapisz",
    "Mixed Active Content is not allowed. HTTPS address for ONLYOFFICE Docs is required." : "Aktywna Zawartość Mieszana nie jest dozwolona. Adres HTTPS jest wymagany dla ONLYOFFICE Docs.",
    "Restrict access to editors to following groups" : "Ogranicz dostęp do edytorów dla tych grup",
    "review" : "recenzja",
    "form filling" : "wypełnianie formularza",
    "comment" : "komentarz",
    "custom filter" : "niestandardowy filtr",
    "download" : "pobierz",
    "Server settings" : "Ustawienia serwera",
    "Common settings" : "Ustawienia ogólne",
    "Editor customization settings" : "Ustawienia edytorów",
    "The customization section allows personalizing the editor interface" : "Ta sekcja pozwala na personalizację interefejsu edytorów",
    "Display Chat menu button" : "Wyświetl menu Czatu",
    "Display the header more compact" : "Wyświetlaj bardziej kompaktowy nagłówek",
    "Display Feedback & Support menu button" : "Wyświetlaj Opinie i Support",
    "Display Help menu button" : "Wyświetlaj menu pomocy",
    "Display monochrome toolbar header" : "Wyświetl monochromatyczny nagłówek paska narzędzi",
    "Save as" : "Zapisz jako",
    "File saved" : "Plik zapisany",
    "Insert image" : "Wstaw obraz",
    "Select recipients" : "Wybierz odbiorców",
    "Connect to demo ONLYOFFICE Docs server" : "Połącz się z serwerem demo ONLYOFFICE Docs",
    "This is a public test server, please do not use it for private sensitive data. The server will be available during a 30-day period." : "To jest publiczny testowy serwer, proszę nie używać go do prywatnych danych. Serwer będzie dostępny przez 30 dni.",
    "The 30-day test period is over, you can no longer connect to demo ONLYOFFICE Docs server." : "Upłyneło 30 dni, nie możesz się już łączyć z serwerem demo.",
    "You are using public demo ONLYOFFICE Docs server. Please do not store private sensitive data." : "Używasz publicznego serwera demo. Nie przechowuj tu prywatnych danych.",
    "Select file to compare": "Wybierz plik do porównania",
    "Review mode for viewing": "Tryb recenzji dla przeglądania",
    "Markup": "Wprowadzone zmiany",
    "Final": "Zmieniony dokument",
    "Original": "Oryginalny dokument",
    "version": "wersja",
    "Disable certificate verification (insecure)": "Wyłącz weryfikację certyfikatu (niebezpieczne)",
    "Keep intermediate versions when editing (forcesave)": "Zachowuj wersje pośrednie w trakcie edycji (zapisuj automatycznie)",
    "Use ONLYOFFICE to generate a document preview (it will take up disk space)": "Skorzystaj z ONLYOFFICE, aby wygenerować podgląd dokumentu (zajmie to miejsce na dysku)",
    "Keep metadata for each version once the document is edited (it will take up disk space)": "Zachowaj metadane dla każdej wersji, gdy dokument jest edytowany (zajmie to miejsce na dysku)",
    "Clear": "Wyczyść",
    "All history successfully deleted": "Cała historia została pomyślnie usunięta",
    "Create": "Utwórz",
    "Select template" : "Wybierz szablon",
    "Invalid file provided" : "Wprowadzono niewłaściwy plik",
    "Empty": "Pusty",
    "Error" : "Błąd",
    "Add a new template": "Dodaj nowy szablon",
    "Template already exists": "Szablon już istnieje",
    "Template must be in OOXML format": "Szablon musi być w formacie OOXML",
    "Template successfully added": "Szablon został pomyślnie dodany",
    "Template successfully deleted": "Szablon został pomyślnie usunięty",
    "Common templates": "Popularne szablony",
    "Failed to delete template": "Nie udało się usunąć szablonu",
    "File has been converted. Its content might look different.": "Plik został przekonwertowany. Jego zawartość może wyglądać inaczej.",
    "Download as": "Pobierz jako",
    "Download": "Pobierz",
    "Origin format": "Oryginalny format",
    "Failed to send notification": "Nie udało się wysłać powiadomienia",
    "Notification sent successfully": "Powiadomienie zostało wysłane",
    "%1\$s mentioned in the %2\$s: \"%3\$s\".": "%1\$s dodał(a) Cię w %2\$s następujący komentarz: \"%3\$s\".",
    "Choose a format to convert {fileName}": "Wybierz format, do którego chcesz przekonwertować {fileName}",
    "Form template": "Szablon formularza",
    "Form template from existing text file": "Szablon formularza z istniejącego pliku tekstowego",
    "Create form": "Utwórz formularz",
    "Fill in form in ONLYOFFICE": "Wypełnić formularz w ONLYOFFICE",
    "Create new Form template": "Utwórz nowy szablon formularza",
    "Please update ONLYOFFICE Docs to version 7.0 to work on fillable forms online": "Zaktualizuj ONLYOFFICE Docs do wersji 7.0, aby działały w formularzach do wypełniania online",
    "Security": "Bezpieczeństwo",
    "Light": "Jasny",
    "Classic Light": "Klasyczny jasny",
    "Dark": "Ciemny"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");