<div id="{dialog_name}" title="{dialog_title}">
    <ul class="onlyoffice-template-container container-dialog">
        <li class="onlyoffice-template-item item-dialog">
            <label for="">
                <img src="" alt="">
                <p></p>
            </label>
        </li>
    </ul>
</div>