/**
 *
 * (c) Copyright Ascensio System SIA 2023
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#content .section-onlyoffice h2 .icon-info {
    padding-top: 17px;
}
.onlyoffice-error {
    color: red;
}
.onlyoffice-header {
    display: inline-block;
    margin-top: 16px;
}
.section-onlyoffice input {
    display: block;
    width: 250px;
}
.onlyoffice-hide {
    display: none;
}
#onlyofficeAdv {
    cursor: pointer;
    text-decoration: none;
}
#onlyofficeAdv .icon {
    display: inline-block;
    margin-bottom: -3px;
}
#onlyofficeAddrSave {
    float: left;
}
#onlyofficeSave {
    margin-bottom: 25px;
}
.onlyoffice-demo {
    margin-left: 90px;
}
#s2id_onlyofficeLimitGroups {
    margin-bottom: 16px;
}
.onlyoffice-exts {
    column-width: 100px;
    -moz-column-width: 100px;
    -webkit-column-width: 100px;
}
.onlyoffice-tables {
    column-width: 140px;
    -moz-column-width: 140px;
    -webkit-column-width: 140px;
}
#personal-show + label {
    margin-top: -25px;
    margin-left: 230px;
}
.onlyoffice-option-desc {
    margin-left: 20px;
}
