<li data-id="" class="onlyoffice-template-item" >
    <img src="" />
    <p></p>
    <span class="onlyoffice-template-download"></span>
    <span class="onlyoffice-template-delete icon-delete"></span>
</li>